@@ -2,6 +2,7 @@
 #include "example_part.h"
 #include <kaboutdata.h>
 #include <kinstance.h>
+#include <kiconloader.h>
 #include <klocale.h>
 #include <kdebug.h>
 
@@ -26,19 +27,16 @@ ExampleFactory::ExampleFactory( QObject* parent, const char* name )
 ExampleFactory::~ExampleFactory()
 {
     if ( s_global )
+    {
+      delete s_global->aboutData();
       delete s_global;
+    }
 }
 
-QObject* ExampleFactory::create( QObject* parent, const char* name, const char* classname, const QStringList & )
+KParts::Part* ExampleFactory::createPart( QWidget *, const char *, QObject* parent, const char* name, const char* classname, const QStringList & )
 {
-/*
-    if ( parent && !parent->inherits("KoDocument") )
-    {
-	kdDebug(31000) << "ExampleFactory: parent does not inherit KoDocument" << endl;
-	return 0;
-    }
-*/
-
+    // If classname is "KoDocument", our host is a koffice application
+    // otherwise, the host wants us as a simple part, so switch to readonly.
     bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
 
     ExamplePart *part = new ExamplePart( parent, name, !bWantKoDocument );
@@ -46,7 +44,9 @@ QObject* ExampleFactory::create( QObject* parent, const char* name, const char*
     if ( !bWantKoDocument )
       part->setReadWrite( false );
 
+    // Tell the factory base class that we created the object (mandatory)
     emit objectCreated(part);
+
     return part;
 }
 
@@ -66,6 +66,9 @@ KInstance* ExampleFactory::global()
     {
         s_global = new KInstance( aboutData() );
         // Add any application-specific resource directories here
+
+	// Tell the iconloader about share/apps/koffice/icons
+	s_global->iconLoader()->addAppDir("koffice");
     }
 
     return s_global;
