@@ -44,5 +44,8 @@ public:
     virtual const bool I_filter(const QCString &file, const QCString &from,
 				QDomDocument &document, const QCString &to,
 				const QString &config=QString::null);
+    virtual const bool I_filter(const QCString &file, KoDocument *document,
+				const QCString &from, const QCString &to,
+				const QString &config=QString::null);
 };
 #endif // CSVFILTER_H
