@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 1999 Werner Trobin <trobin@kde.org>
+   Copyright (C) 1999 Werner Trobin <wtrobin@carinthia.com>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,27 +21,18 @@
 #define POWERPOINTFILTER_H
 
 #include <filterbase.h>
-#include <pptxml.h>
 
-class PowerPointFilter:
-    public FilterBase
-{
+class PowerPointFilter : public FilterBase {
+
     Q_OBJECT
 
 public:
-    PowerPointFilter(
-        const myFile &mainStream,
-        const myFile &currentUser,
-        const myFile &pictures);
-    virtual ~PowerPointFilter();
-    virtual bool filter();
+    PowerPointFilter() : FilterBase() {}
+    virtual ~PowerPointFilter() {}
     virtual const QDomDocument * const part();
-
+    
 private:
     PowerPointFilter(const PowerPointFilter &);
     const PowerPointFilter &operator=(const PowerPointFilter &);
-
-    PptXml *m_tree;
 };
-#endif
-
+#endif // POWERPOINTFILTER_H
