@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 1999 Werner Trobin <trobin@kde.org>
+   Copyright (C) 1999 Werner Trobin <wtrobin@carinthia.com>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,32 +21,23 @@
 #define WORDFILTER_H
 
 #include <filterbase.h>
-#include <qcstring.h>
-class myFile;
-class WinWordDoc;
+#include <winworddoc.h>
+#include <myfile.h>
+
+class WordFilter : public FilterBase {
 
-class WordFilter :
-    public FilterBase
-{
     Q_OBJECT
 
 public:
     WordFilter(const myFile &mainStream, const myFile &table0Stream,
                const myFile &table1Stream, const myFile &dataStream);
     virtual ~WordFilter();
-
-    virtual bool filter();
-    virtual bool plainString() const { return true; }
-    virtual QCString CString() const;
-
-signals:
-    void internalCommDelayStream( const char* delay );
-    void internalCommShapeID( unsigned int& shapeID );
+    virtual const QDomDocument * const part();
+    virtual const bool filter();
 
 private:
     WordFilter(const WordFilter &);
     const WordFilter &operator=(const WordFilter &);
-    QCString m_result;
 
     WinWordDoc *myDoc;
 };
