@@ -1,5 +1,5 @@
 /**
- * $Id: kchart_view.cc,v 1.39 2000/04/23 08:05:27 wtrobin Exp $
+ * $Id: kchart_view.cc,v 1.42 2000/05/31 13:46:23 wtrobin Exp $
  *
  * Kalle Dalheimer <kalle@kde.org>
  */
@@ -15,7 +15,8 @@
 #include <qpainter.h>
 #include <kaction.h>
 #include <kglobal.h>
-//#include <iostream>
+#include <klocale.h>
+#include <kiconloader.h>
 #include <kdebug.h>
 
 using namespace std;
@@ -28,47 +29,41 @@ KChartView::KChartView( KChartPart* part, QWidget* parent, const char* name )
     setInstance( KChartFactory::global() );
     setXMLFile( "kchart.rc" );
 
-    m_wizard = new KAction( tr("Customize with &wizard"),
+    m_wizard = new KAction( i18n("Customize with &Wizard"),
 			    "wizard", 0,
 			    this, SLOT( wizard() ),
 			    actionCollection(), "wizard");
-    m_edit = new KAction( tr("&Edit data"), "pencil", 0,
+    m_edit = new KAction( i18n("&Edit Data"), "pencil", 0,
 			 this, SLOT( edit() ),
                          actionCollection(), "edit");
-    m_config = new KAction( tr( "&Config" ), "options", 0,
+    m_config = new KAction( i18n( "&Config" ), "options", 0,
 			    this, SLOT( config() ),
 			    actionCollection(), "config" );
-    m_loadconfig = new KAction( tr("Load config"), "loadconfig",
-				0,
-				this, SLOT( loadConfig() ),
+    m_loadconfig = new KAction( i18n("&Load Config"),
+				"loadconfig", 0, this,
+				SLOT( loadConfig() ),
 				actionCollection(), "loadconfig");
-    m_saveconfig = new KAction( tr("Save config"), "saveconfig",
-				0,
-				this, SLOT( saveConfig() ),
+    m_saveconfig = new KAction( i18n("&Save Config"),
+				"saveconfig",	0, this,
+				SLOT( saveConfig() ),
 				actionCollection(), "saveconfig");
-    m_defaultconfig = new KAction( tr("By default"), "defaultconfig",
-				0,
-				this, SLOT( defaultConfig() ),
-				actionCollection(), "defaultconfig");
-
-    m_chartpie = new KAction( tr("Pie"), "cakes",
-				0,
-				this, SLOT( pieChart() ),
-				actionCollection(), "piechart");
-    m_chartline = new KAction( tr("Line"), "lines",
-				0,
-				this, SLOT( lineChart() ),
-				actionCollection(), "linechart");
-    m_chartareas = new KAction( tr("Areas"), "areas",
-				0,
-				this, SLOT( areasChart() ),
-				actionCollection(), "areaschart");
-    m_chartbars = new KAction( tr("Bars"), "bars",
- 				0,
-				this, SLOT( barsChart() ),
-				actionCollection(), "barschart");
-
+    m_defaultconfig = new KAction( i18n("&Default Config"),
+				   "defaultconfig", 0, this,
+				   SLOT( defaultConfig() ),
+				   actionCollection(), "defaultconfig");
 
+    m_chartpie = new KAction( i18n("&Pie"), "cakes", 0, this,
+			      SLOT( pieChart() ), actionCollection(),
+			      "piechart");
+    m_chartline = new KAction( i18n("&Line"), "lines", 0, this,
+			       SLOT( lineChart() ), actionCollection(),
+			       "linechart");
+    m_chartareas = new KAction( i18n("&Areas"), "areas", 0, this,
+				SLOT( areasChart() ), actionCollection(),
+				"areaschart");
+    m_chartbars = new KAction( i18n("&Bars"), "bars", 0, this,
+			       SLOT( barsChart() ), actionCollection(),
+			       "barschart");
 
     // initialize the configuration
     //    loadConfig();
