@@ -13,37 +13,30 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
-#include <KoApplication.h>
+#include <koApplication.h>
 #include <kcmdlineargs.h>
+#include <kaboutdata.h>
 #include <klocale.h>
-#include "kchart_aboutdata.h"
+#include "kchart_factory.h"
 
-using namespace KChart;
-
-namespace KChart
-{
 
 static const KCmdLineOptions options[]=
 {
-	{"+[file]", I18N_NOOP("File to open"),0},
-	KCmdLineLastOption
+	{"+[file]", I18N_NOOP("File To Open"),0},
+	{0,0,0}
 };
 
-}  //namespace KChart
-
-
-extern "C" KCHART_EXPORT int kdemain( int argc, char **argv )
+int main( int argc, char **argv )
 {
-    KCmdLineArgs::init( argc, argv, newKChartAboutData());
+    KCmdLineArgs::init( argc, argv, KChartFactory::aboutData());
     KCmdLineArgs::addCmdLineOptions( options );
-
+    
     KoApplication app;
-    if (!app.start())
-	return 1;
+    app.start();
     app.exec();
 
     return 0;
