@@ -14,31 +14,43 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
-#include <KoApplication.h>
+#include "kformula_doc.h"
+#include "kformula_shell.h"
+
+#include <koApplication.h>
+#include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
-#include <dcopclient.h>
+#include "kformula_factory.h"
 
-#include "kformula_aboutdata.h"
 
 static const KCmdLineOptions options[]=
 {
-        {"+[file]", I18N_NOOP("File to open"),0},
-        KCmdLineLastOption
+	{"+[file]", I18N_NOOP("File To Open"),0},
+	{0,0,0}
 };
 
-extern "C" KFORMULA_EXPORT int kdemain( int argc, char **argv )
+extern "C"
 {
-    KCmdLineArgs::init( argc, argv, newKFormulaAboutData() );
+    void* init_libkformulapart();
+}
+
+int main( int argc, char **argv )
+{
+    KCmdLineArgs::init( argc, argv, KFormulaFactory::aboutData());
     KCmdLineArgs::addCmdLineOptions( options );
 
     KoApplication app;
 
-    if (!app.start())
-        return 1;
-    return app.exec();
+    init_libkformulapart();
+
+    app.start();
+
+    app.exec();
+
+    return 0;
 }
