@@ -1,6 +1,6 @@
 /* -*- C++ -*-
 
-  $Id: KIllustrator_view.cc,v 1.54 2000/04/23 00:56:55 granroth Exp $
+  $Id: KIllustrator_view.cc,v 1.56 2000/05/19 13:07:31 sattler Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
@@ -113,18 +113,6 @@ KIllustratorView::KIllustratorView (QWidget* parent, const char* name,
   // restore default settings
   PStateManager::instance ();
 
-  zFactors.resize (8);
-  zFactors[0] = 0.5;
-  zFactors[1] = 1.0;
-  zFactors[2] = 1.5;
-  zFactors[3] = 2.0;
-  zFactors[4] = 4.0;
-  zFactors[5] = 6.0;
-  zFactors[6] = 8.0;
-  zFactors[7] = 10.0;
-
-  Canvas::initZoomFactors (zFactors);
-
   cout << "connect doc" << endl;
   /*
   QObject::connect (m_pDoc,
@@ -150,7 +138,7 @@ void KIllustratorView::createGUI()
     // File menu
     m_import = new KAction( i18n("Import..."), 0, this, SLOT( slotImport() ), actionCollection(), "import" );
     m_export = new KAction( i18n("Export..."), 0, this, SLOT( slotExport() ), actionCollection(), "export" );
-    m_docInfo = new KAction( i18n("Document Info..."), 0, this, SLOT( slotDocumentInfo() ), actionCollection(), "documentInfo" );
+    //    m_docInfo = new KAction( i18n("Document Info..."), 0, this, SLOT( slotDocumentInfo() ), actionCollection(), "documentInfo" );
 	
     // Insert menu
     m_insertBitmap = new KAction( i18n("Insert Bitmap..."), 0, this, SLOT( slotInsertBitmap() ), actionCollection(), "insertBitmap" );
@@ -212,8 +200,27 @@ void KIllustratorView::createGUI()
     m_blend = new KAction( i18n("Blend ..."), 0, this, SLOT( slotBlend() ), actionCollection(), "blend" );
 
     // Extras menu
+    m_loadPalette = new KAction( i18n("Load Palette ..."), 0, this, SLOT( slotLoadPalette() ), actionCollection(), "loadPalette" );
     m_options = new KAction( i18n("Options ..."), 0, this, SLOT( slotOptions() ), actionCollection(), "options" );
 
+    //
+    m_viewZoom = new KSelectAction (i18n ("Zoom"), 0, actionCollection (), 
+				    "view_zoom");
+    QStringList zooms;
+    zooms << "50%";
+    zooms << "100%";
+    zooms << "150%";
+    zooms << "200%";
+    zooms << "400%";
+    zooms << "600%";
+    zooms << "800%";
+    zooms << "1000%";
+
+    ((KSelectAction *) m_viewZoom)->setItems (zooms);
+    connect (((KSelectAction *) m_viewZoom), 
+	     SIGNAL(activated(const QString &)), 
+             this, SLOT(slotViewZoom(const QString &))); 
+    ((KSelectAction *) m_viewZoom)->setCurrentItem (2);
     // Colorbar action
 
     QValueList<QColor> colorList;
@@ -1196,4 +1203,17 @@ void KIllustratorView::slotDocumentInfo () {
   DocumentInfo::showInfo (m_pDoc->gdoc ());
 }
 
+void KIllustratorView::slotLoadPalette () {
+  // TODO
+}
+
+void KIllustratorView::slotViewZoom (const QString& s) {
+  QString z (s);
+  z = z.replace (QRegExp ("%"), "");
+  z = z.simplifyWhiteSpace ();
+  float zoom = z.toFloat () / 100.0;
+  if (zoom != canvas->getZoomFactor ())
+    canvas->setZoomFactor (zoom);
+}
+
 #include "KIllustrator_view.moc"
