@@ -1,6 +1,6 @@
 /* -*- C++ -*-
 
-  $Id: DuplicateCmd.h,v 1.2 1999/09/23 06:54:12 sattler Exp $
+  $Id: DuplicateCmd.h,v 1.3 2000/05/16 13:25:21 sattler Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
@@ -32,6 +32,7 @@ class GDocument;
 class GObject;
 
 class DuplicateCmd : public Command {
+  Q_OBJECT
 public:
   DuplicateCmd (GDocument* doc);
   ~DuplicateCmd ();
@@ -39,9 +40,15 @@ public:
   void execute ();
   void unexecute ();
 
+  static void resetRepetition ();
+  static void setRepetitionOffset (float dx, float dy);
+
 private:
   GDocument* document;
   list<GObject*> objects, new_objects;
+
+  static bool repeatCmd; // repeat command with given offsets
+  static float repOffX, repOffY; // offset for repetition
 };
 
 #endif
