@@ -1,6 +1,6 @@
 /* -*- C++ -*-
 
-  $Id: TranslateCmd.h,v 1.1.1.1 1998/07/09 13:33:29 sattler Exp $
+  $Id: TranslateCmd.h,v 1.2 2000/05/16 13:25:21 sattler Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
@@ -31,12 +31,16 @@
  * Translates the selected objects of the given document <tt>doc</tt>
  * by the values of <tt>x</tt> and <tt>y</tt>.
  */
-class TranslateCmd : public ObjectManipCmd {
+class TranslateCmd : public ObjectManipCmd { 
+  Q_OBJECT
 public:
   TranslateCmd (GDocument* doc, float x, float y);
 
   void execute ();
 
+  float xOffset () const { return dx; }
+  float yOffset () const { return dy; }
+
 private:
   float dx, dy;
 };
