@@ -1,6 +1,5 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2000, 2001 David Faure <david@mandrakesoft.com>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,29 +22,27 @@
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <kdebug.h>
-#include <config.h>
 
 #include "koshell_shell.h"
 
-static const char* description=I18N_NOOP("KOffice Workspace");
-static const char* version=VERSION;
+// Damn, how is this called in StarOffice ?
+static const char* description=I18N_NOOP("KOffice Common Window");
+static const char* version="0.3";
 
 int main( int argc, char **argv )
 {
-  KAboutData * aboutData = new KAboutData( "koshell", I18N_NOOP("KOffice Workspace"),
+  KAboutData * aboutData = new KAboutData( "koshell", I18N_NOOP("KOShell"),
      version, description, KAboutData::License_GPL,
-       "(c) 1998-2002, Torben Weis");
-  aboutData->addAuthor("Sven Lüppken", I18N_NOOP("Current Maintainer"), "sven@kde.org");
-  aboutData->addAuthor("Torben Weis", 0, "weis@kde.org");
-  aboutData->addAuthor("David Faure", 0, "david@mandrakesoft.com");
-  
+       "(c) 1998-2000, Torben Weis");
+  aboutData->addAuthor("Torben Weis",0, "weis@kde.org");
+
   KCmdLineArgs::init( argc, argv, aboutData );
   //KCmdLineArgs::addCmdLineOptions( options );
 
   KoApplication app;
-
+  
   KoShellWindow *shell = new KoShellWindow;
-
+  
   shell->show();
 
   return app.exec();
