@@ -1,4 +1,3 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
 
@@ -21,17 +20,28 @@
 #ifndef confpiedia_h
 #define confpiedia_h
 
+#include <qdialog.h>
 #include <qframe.h>
-#include "global.h"
-#include <qcombobox.h>
 #include <qpen.h>
-#include <knuminput.h>
 #include <qbrush.h>
+#include <qcombobox.h>
+#include <qlineedit.h>
+
+#include "global.h"
+
+#ifndef max
+#define max(a,b) ((a)>(b)?(a):(b))
+#endif
+
 class QLabel;
 class QGroupBox;
 class QPushButton;
-class QPainter;
 class QComboBox;
+class QPainter;
+
+/******************************************************************/
+/* class PiePreview                                               */
+/******************************************************************/
 
 class PiePreview : public QFrame
 {
@@ -42,13 +52,13 @@ public:
     ~PiePreview() {}
 
     void setAngle( int _angle )
-        { angle = _angle; repaint( true ); }
+    { angle = _angle; repaint( true ); }
     void setLength( int _len )
-        { len = _len; repaint( true ); }
+    { len = _len; repaint( true ); }
     void setType( PieType _type )
-        { type = _type; repaint( true ); }
-    void setPenBrush( const QPen &_pen, const QBrush &_brush )
-        { pen = _pen; brush = _brush; repaint( true ); }
+    { type = _type; repaint( true ); }
+    void setPenBrush( QPen _pen, QBrush _brush )
+    { pen = _pen; brush = _brush; repaint( true ); }
 
 protected:
     void drawContents( QPainter* );
@@ -60,7 +70,11 @@ protected:
 
 };
 
-class ConfPieDia : public QWidget
+/******************************************************************/
+/* class ConfPieDia                                               */
+/******************************************************************/
+
+class ConfPieDia : public QDialog
 {
     Q_OBJECT
 
@@ -68,37 +82,40 @@ public:
     ConfPieDia( QWidget* parent, const char* );
     ~ConfPieDia();
 
-    void setAngle( int _angle );
-    void setLength( int _len );
-    void setType( PieType _type );
-    void setPenBrush( const QPen &_pen, const QBrush &_brush );
-    void resetConfigChangedValues();
+    void setAngle( int _angle )
+    { angle = _angle; QString str; str.sprintf( "%d", _angle ); eAngle->setText( str ); piePreview->setAngle( angle ); }
+    void setLength( int _len )
+    { len = _len; QString str; str.sprintf( "%d", _len ); eLen->setText( str ); piePreview->setLength( len ); }
+    void setType( PieType _type )
+    { type = _type; cType->setCurrentItem( _type ); piePreview->setType( type ); }
+    void setPenBrush( QPen _pen, QBrush _brush )
+    { pen = _pen; brush = _brush; piePreview->setPenBrush( pen, brush );  }
 
-    int getAngle() const { return angle; }
-    int getLength() const { return len; }
-    PieType getType() const { return type; }
-    int getPieConfigChange() const;
+    int getAngle()
+    { return angle; }
+    int getLength()
+    { return len; }
+    PieType getType()
+    { return type; }
 
 protected:
-    bool m_bTypeChanged, m_bAngleChanged, m_bLengthChanged;
     QLabel *lType, *lAngle, *lLen;
-    KIntNumInput *eAngle, *eLen;
-    QGroupBox *gSettings;
+    QLineEdit *eAngle, *eLen;
+    QGroupBox *gSettings, *gPreview;
     PiePreview *piePreview;
+    QPushButton *okBut, *applyBut, *cancelBut;
     QComboBox *cType;
 
-    PieType type;
-    PieType oldType;
-
     int angle, len;
-    int oldAngle, oldLen;
+    PieType type;
+    QPen pen;
+    QBrush brush;
 
 protected slots:
-    void lengthChanged( int );
-    void angleChanged( int );
+    void lengthChanged( const QString & );
+    void angleChanged( const QString & );
     void typeChanged( int );
     void Apply() { emit confPieDiaOk(); }
-    void slotReset();
 
 signals:
     void confPieDiaOk();
@@ -106,3 +123,5 @@ signals:
 };
 
 #endif
+
+
