@@ -48,7 +48,7 @@ KPAutoformObject::KPAutoformObject()
     gType = BCT_GHORZ;
     drawShadow = false;
     redrawPix = false;
-    unbalanced = FALSE;
+    unbalanced = false;
     xfactor = 100;
     yfactor = 100;
 }
@@ -163,7 +163,7 @@ void KPAutoformObject::save( ostream& out )
     int len = afDir.length();
     QString str = filename;
     str = str.remove( 0, len );
-    out << indent << "<FILENAME value=\"" << str.ascii() << "\"/>" << endl;
+    out << indent << "<FILENAME value=\"" << str.utf8() << "\"/>" << endl;
     out << indent << "<FILLTYPE value=\"" << static_cast<int>( fillType ) << "\"/>" << endl;
     out << indent << "<GRADIENT red1=\"" << gColor1.red() << "\" green1=\"" << gColor1.green()
 	<< "\" blue1=\"" << gColor1.blue() << "\" red2=\"" << gColor2.red() << "\" green2=\""
