@@ -96,7 +96,7 @@ void KPPresStructObjectItem::setPage( KPBackGround *p, int pgnum )
     page = p;
     pageNum = pgnum;
     if ( page && !parent() )
-	setPixmap( 0, BarIcon( "dot" ) );
+	setPixmap( 0, KPBarIcon( "dot" ) );
 }
 
 /*================================================================*/
@@ -107,46 +107,46 @@ void KPPresStructObjectItem::setObject( KPObject *o, int num )
 	switch ( object->getType() ) {
 	case OT_PICTURE:
 	    setText( 0, i18n( "Picture (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_picture" ) );
+	    setPixmap( 0, KPBarIcon( "mini_picture" ) );
 	    break;
 	case OT_LINE:
 	    setText( 0, i18n( "Line (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_line" ) );
+	    setPixmap( 0, KPBarIcon( "mini_line" ) );
 	    break;
 	case OT_RECT:
 	    setText( 0, i18n( "Rectangle (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_rect" ) );
+	    setPixmap( 0, KPBarIcon( "mini_rect" ) );
 	    break;
 	case OT_ELLIPSE:
 	    setText( 0, i18n( "Circle/Ellipse (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_circle" ) );
+	    setPixmap( 0, KPBarIcon( "mini_circle" ) );
 	    break;
 	case OT_TEXT:
 	    setText( 0, i18n( "Text (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_text" ) );
+	    setPixmap( 0, KPBarIcon( "mini_text" ) );
 	    break;
 	case OT_AUTOFORM:
 	    setText( 0, i18n( "Autoform (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_autoform" ) );
+	    setPixmap( 0, KPBarIcon( "mini_autoform" ) );
 	    break;
 	case OT_CLIPART:
 	    setText( 0, i18n( "Clipart (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_clipart" ) );
+	    setPixmap( 0, KPBarIcon( "mini_clipart" ) );
 	    break;
 	case OT_UNDEFINED:
 	    setText( 0, i18n( "Undefined (%1)" ).arg( num + 1 ) );
 	    break;
 	case OT_PIE:
 	    setText( 0, i18n( "Pie/Arc/Chord (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_pie" ) );
+	    setPixmap( 0, KPBarIcon( "mini_pie" ) );
 	    break;
 	case OT_PART:
 	    setText( 0, i18n( "Embedded Part (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "mini_part" ) );
+	    setPixmap( 0, KPBarIcon( "mini_part" ) );
 	    break;
 	case OT_GROUP:
 	    setText( 0, i18n( "Group Object (%1)" ).arg( num + 1 ) );
-	    setPixmap( 0, BarIcon( "group" ) );
+	    setPixmap( 0, KPBarIcon( "group" ) );
 	    break;
 	}
     }
@@ -179,7 +179,7 @@ int KPPresStructObjectItem::getPageNum()
 /*================================================================*/
 KPPresStructView::KPPresStructView( QWidget *parent, const char *name,
                                     KPresenterDoc *_doc, KPresenterView *_view )
-    : QDialog( parent, name, FALSE ), doc( _doc ), view( _view )
+    : QDialog( parent, name, false ), doc( _doc ), view( _view )
 {
     hsplit = new QSplitter( this );
     setupSlideList();
@@ -194,9 +194,9 @@ void KPPresStructView::setupSlideList()
     slides = new QListView( hsplit );
     slides->addColumn( i18n( "Slide Nr." ) );
     slides->addColumn( i18n( "Slide Title" ) );
-    slides->header()->setMovingEnabled( FALSE );
-    slides->setAllColumnsShowFocus( TRUE );
-    slides->setRootIsDecorated( TRUE );
+    slides->header()->setMovingEnabled( false );
+    slides->setAllColumnsShowFocus( true );
+    slides->setRootIsDecorated( true );
     slides->setSorting( -1 );
 
     for ( int i = doc->getPageNums() - 1; i >= 0; --i ) {
@@ -222,9 +222,9 @@ void KPPresStructView::setupPagePreview()
     box->setSpacing( 5 );
 
     showPreview = new QCheckBox( i18n( "&Show Preview" ), box );
-    showPreview->setChecked( TRUE );
+    showPreview->setChecked( true );
     // #### for now
-    showPreview->setEnabled( FALSE );
+    showPreview->setEnabled( false );
 
     slidePreview = new KPSlidePreview( box, doc, view );
     connect( slides, SIGNAL( selectionChanged( QListViewItem * ) ),
@@ -245,7 +245,7 @@ void KPPresStructView::makeStuffVisible( QListViewItem *item )
 {
     if ( !item )
 	return;
-    
+
     if ( !item->parent() )
 	view->skipToPage( atoi( item->text( 0 ) ) - 1 );
     else {
@@ -262,7 +262,7 @@ void KPPresStructView::makeStuffVisible( QListViewItem *item )
 	int obj = s.toInt() - 1;
 	KPObject *kpobject = doc->objectList()->at( obj );
 	QRect rect( kpobject->getBoundingRect( 0, 0 ) );
-	kpobject->setSelected( TRUE );
+	kpobject->setSelected( true );
 	doc->repaint( kpobject );
 	rect.setLeft( rect.left() - 20 );
 	rect.setTop( rect.top() - 20 );
