@@ -63,7 +63,7 @@ void KSpreadEditWidget::slotDoneEdit()
 void KSpreadEditWidget::keyPressEvent ( QKeyEvent* _ev )
 {
   // Dont handle special keys and accelerators
-  if ( _ev->state() & ( Qt::AltButton | Qt::ControlButton ) )
+if ( _ev->state() & ( Qt::AltButton | Qt::ControlButton ) )
   {
     QLineEdit::keyPressEvent( _ev );
     return;
@@ -173,6 +173,7 @@ KSpreadCanvas::KSpreadCanvas( QWidget *_parent, KSpreadView *_view, KSpreadDoc*
 
   choose_visible = false;
 
+  labelComment=0;
   setFocus();
 }
 
@@ -273,8 +274,8 @@ void KSpreadCanvas::gotoLocation( const KSpreadPoint& _cell )
 
 void KSpreadCanvas::gotoLocation( int x, int y, KSpreadTable* table, bool make_select )
 {
-  kdDebug(36001) << "KSpreadCanvas::gotoLocation" << " x=" << x << " y=" << y <<
-    " table=" << table << " make_select=" << (make_select ? "true" : "false" ) << endl;
+  //kdDebug(36001) << "KSpreadCanvas::gotoLocation" << " x=" << x << " y=" << y <<
+  //  " table=" << table << " make_select=" << (make_select ? "true" : "false" ) << endl;
   if ( table )
     m_pView->setActiveTable( table );
   else
@@ -560,9 +561,11 @@ void KSpreadCanvas::mouseMoveEvent( QMouseEvent * _ev )
     return;
 
   if ( col < m_iMouseStartColumn )
-    col = m_iMouseStartColumn;
+     col = m_iMouseStartColumn;
+
   if ( row < m_iMouseStartRow )
-    row = m_iMouseStartRow;
+     row = m_iMouseStartRow;
+
 
   if ( row == selection.bottom() && col == selection.right() )
     return;
@@ -690,6 +693,7 @@ void KSpreadCanvas::mousePressEvent( QMouseEvent * _ev )
     int xpos;
     int ypos;
     int w, h;
+
     // No selection or complete rows/columns are selected
     if ( selection.left() == 0 ||
          selection.right() == 0x7fff || selection.bottom() == 0x7fff )
@@ -1152,15 +1156,15 @@ void KSpreadCanvas::keyPressEvent ( QKeyEvent * _ev )
 
     case Key_Right:
 
-      if ( !m_bChoose && markerColumn() == 0xFFFF )
+      if ( !m_bChoose && markerColumn() >= 26*26)//0xFFFF )
         return;
-      if ( m_bChoose && chooseMarkerColumn() == 0xFFFF )
+      if ( m_bChoose && chooseMarkerColumn() >= 26*26)//0xFFFF )
         return;
 
       if ( m_bChoose )
-        chooseGotoLocation( QMIN( 0x7FFF, chooseMarkerColumn() + 1 ), chooseMarkerRow(), 0, make_select );
+        chooseGotoLocation( QMIN( 26*26/*0x7FFF*/, chooseMarkerColumn() + 1 ), chooseMarkerRow(), 0, make_select );
       else
-        gotoLocation( QMIN( 0x7FFF, markerColumn() + 1 ), markerRow(), 0, make_select );
+        gotoLocation( QMIN( /*26*26*/0x7FFF, markerColumn() + 1 ), markerRow(), 0, make_select );
 
       return;
 
@@ -1243,7 +1247,7 @@ void KSpreadCanvas::keyPressEvent ( QKeyEvent * _ev )
     default:
 
       // No null character ...
-      if ( _ev->ascii() == 0 || !m_pView->koDocument()->isReadWrite() )
+      if ( _ev->text().isEmpty() || !m_pView->koDocument()->isReadWrite() )
       {
         _ev->accept();
         return;
@@ -1251,7 +1255,7 @@ void KSpreadCanvas::keyPressEvent ( QKeyEvent * _ev )
 
       if ( !m_pEditor && !m_bChoose )
       {
-        if ( _ev->ascii() == '*' )
+        if ( _ev->text() == QString::fromLatin1("*") )
           createEditor( FormulaEditor );
         else
         {
@@ -1439,6 +1443,13 @@ void KSpreadCanvas::drawMarker( QPainter * _painter )
 {
   bool own_painter = FALSE;
 
+  //delete labelComment when you change position
+  if(labelComment)
+        {
+        delete labelComment;
+        labelComment=0;
+        }
+
   if ( _painter == 0L )
   {
     _painter = new QPainter();
@@ -1505,7 +1516,7 @@ void KSpreadCanvas::drawMarker( QPainter * _painter )
   	{
   	if(activeTable()->getLcMode())
   		{
-  		buffer="L"+tmp.setNum(m_iMarkerRow); 
+  		buffer="L"+tmp.setNum(m_iMarkerRow);
 	  	buffer+="C"+tmp.setNum(m_iMarkerColumn);
   		}
   	else
@@ -1532,28 +1543,34 @@ void KSpreadCanvas::drawMarker( QPainter * _painter )
   	}
   else
   	{
-  	
+
   	if(activeTable()->getLcMode())
   		{
- 	 	buffer="L"+tmp.setNum(m_iMarkerRow); 
-	  	buffer+="C"+tmp.setNum(m_iMarkerColumn);	
+ 	 	//buffer="L"+tmp.setNum(m_iMarkerRow);
+	  	//buffer+="C"+tmp.setNum(m_iMarkerColumn);
+                buffer=tmp.setNum( (selection.bottom()-selection.top()+1) )+"Lx";
+                if(selection.right()==0x7FFF)
+                        buffer+=tmp.setNum((26*26-selection.left()+1))+"C";
+                else
+                        buffer+=tmp.setNum((selection.right()-selection.left()+1))+"C";
   		}
   	else
   		{
 	  	//Problem columnLabel return @@@@ when column >26*26
  	 	//=> it's not a good display
   		//=> for the moment I display pos of marker
-  		//buffer=activeTable()->columnLabel( selection.left() );
-  		//buffer+=tmp.setNum(selection.top());
-  		//buffer+=":";
-  		//buffer+=activeTable()->columnLabel( selection.right() );
-  		//buffer+=tmp.setNum(selection.bottom());
-  		buffer=activeTable()->columnLabel( m_iMarkerColumn );
-  		buffer+=tmp.setNum(m_iMarkerRow);
+  		buffer=activeTable()->columnLabel( selection.left() );
+  		buffer+=tmp.setNum(selection.top());
+  		buffer+=":";
+  		buffer+=activeTable()->columnLabel( selection.right() );
+  		buffer+=tmp.setNum(selection.bottom());
+  		//buffer=activeTable()->columnLabel( m_iMarkerColumn );
+  		//buffer+=tmp.setNum(m_iMarkerRow);
   		}
   	}
 
   m_pPosWidget->setText(buffer);
+
 }
 
 void KSpreadCanvas::updateChooseMarker( const QRect& _old, const QRect& _new )
@@ -1841,8 +1858,8 @@ if(selected)
 		size=QMAX(m_pView->activeTable()->rowLayout(i)->height(this),size);
 	for(int i=selection.top()+1;i<=selection.bottom();i++)
 		m_pView->vBorderWidget()->resizeRow(size,i );
-	}  
-  
+	}
+
 }
 
 void KSpreadCanvas::equalizeColumn()
@@ -1859,9 +1876,58 @@ if(selected)
 		size=QMAX(m_pView->activeTable()->columnLayout(i)->width(this),size);
 	for(int i=selection.left()+1;i<=selection.right();i++)
 		m_pView->hBorderWidget()->resizeColumn(size,i );
-	}  
+	}
 
 }
+
+void KSpreadCanvas::showComment()
+{
+QPainter painter;
+KSpreadCell* cell = activeTable()->cellAt( marker() );
+QString tmp;
+int pos=0;
+int pos1=0;
+int index=0;
+int line=0;
+int start=0;
+if(labelComment)
+        {
+        delete labelComment;
+        labelComment=0;
+        }
+tmp=cell->getComment();
+int len=tmp.length();
+
+do
+{
+  pos=tmp.find("\n",pos);
+  if(QMAX((pos-pos1),index)!=index)
+        {
+        index=QMAX((pos-pos1),index);
+        start=pos1;
+        }
+  pos++;
+  pos1=pos;
+  line++;
+}
+while(pos!=len);
+painter.begin( this );
+
+len = painter.fontMetrics().width(tmp.mid(start,index));
+int hei =painter.fontMetrics().height()*line;
+painter.end();
+
+labelComment=new QLabel(this);
+labelComment->setBackgroundColor( yellow );
+int xpos = activeTable()->columnPos( markerColumn(), this );
+int ypos = activeTable()->rowPos( markerRow(), this );
+int w = cell->width( markerColumn(), this );
+labelComment->setGeometry(xpos +w +10, ypos + 10,len+10, hei+10 ) ;
+labelComment->setAlignment(Qt::AlignVCenter);
+labelComment->setText(tmp);
+labelComment->show();
+}
+
 /****************************************************************
  *
  * KSpreadVBorder
@@ -1874,7 +1940,7 @@ KSpreadVBorder::KSpreadVBorder( QWidget *_parent, KSpreadCanvas *_canvas, KSprea
 
   m_pView = _view;
   m_pCanvas = _canvas;
-
+  size=0;
   setBackgroundMode( PaletteBackground );
   setMouseTracking( TRUE );
   m_bResize = FALSE;
@@ -1917,6 +1983,21 @@ void KSpreadVBorder::mousePressEvent( QMouseEvent * _ev )
     int tmp;
     m_iResizeAnchor = table->topRow( _ev->pos().y() - 3, tmp, m_pCanvas );
     m_iResizePos = _ev->pos().y();
+
+    QString tmpSize,tmp2;
+    int y = table->rowPos( m_iResizeAnchor, m_pCanvas );
+    size=new QLabel(m_pCanvas);
+    size->setBackgroundColor( yellow );
+    tmpSize=i18n("Height : ");
+    tmpSize+=tmp2.setNum(m_iResizePos-y);
+    painter.begin(this);
+    int len = painter.fontMetrics().width(tmpSize );
+    int hei =painter.fontMetrics().height( );
+    painter.end();
+    size->setGeometry(3,y+3,len+2, hei+2 ) ;
+    size->setAlignment(Qt::AlignVCenter);
+    size->setText(tmpSize);
+    size->show();
   }
   else
   {
@@ -1963,6 +2044,8 @@ void KSpreadVBorder::mouseReleaseEvent( QMouseEvent * _ev )
       rl->setHeight( 20, m_pCanvas );
     else
       rl->setHeight( _ev->pos().y() - y, m_pCanvas );
+    delete size;
+    size=0;
   }
 
   m_bSelection = FALSE;
@@ -2051,6 +2134,27 @@ void KSpreadVBorder::mouseMoveEvent( QMouseEvent * _ev )
       m_iResizePos = y + twenty;
     painter.drawLine( 0, m_iResizePos, m_pCanvas->width(), m_iResizePos );
     painter.end();
+    QString tmpSize,tmp2;
+    tmpSize=i18n("Height : ");
+    tmpSize+=tmp2.setNum(m_iResizePos-y);
+    painter.begin(this);
+    int len = painter.fontMetrics().width(tmpSize );
+    int hei =painter.fontMetrics().height( );
+    painter.end();
+    if(!size)
+    	{
+	  size=new QLabel(m_pCanvas);
+	  size->setBackgroundColor( yellow );
+	  size->setGeometry(3,3+y,len+2, hei+2 ) ;
+	  size->setAlignment(Qt::AlignVCenter);
+	  size->setText(tmpSize);
+	  size->show();
+    	}
+    else
+    	{
+	  size->setGeometry(3,3+y,len+2, hei+2 );
+	  size->setText(tmpSize);
+    	}
   }
   // The button is pressed and we are selecting ?
   else if ( m_bSelection )
@@ -2159,9 +2263,9 @@ void KSpreadVBorder::paintEvent( QPaintEvent* _ev )
       painter.setPen( white );
     else
       painter.setPen( colorGroup().text() );
-
-    painter.drawText( 3, ypos +
-                      ( row_lay->height( m_pCanvas ) + painter.fontMetrics().ascent() - painter.fontMetrics().descent() ) / 2, buffer );
+    int len = painter.fontMetrics().width(buffer );
+    painter.drawText( (YBORDER_WIDTH-len)/2, ypos +
+                    ( row_lay->height( m_pCanvas ) + painter.fontMetrics().ascent() - painter.fontMetrics().descent() ) / 2, buffer );
 
     ypos += row_lay->height( m_pCanvas );
   }
@@ -2220,6 +2324,23 @@ void KSpreadHBorder::mousePressEvent( QMouseEvent * _ev )
     int tmp;
     m_iResizeAnchor = table->leftColumn( _ev->pos().x() - 3, tmp, m_pCanvas );
     m_iResizePos = _ev->pos().x();
+
+    int x = table->columnPos( m_iResizeAnchor, m_pCanvas );
+
+    QString tmpSize,tmp2;
+    tmpSize=i18n("Width : ");
+    tmpSize+=tmp2.setNum(m_iResizePos-x);
+    size=new QLabel(m_pCanvas);
+    size->show();
+    painter.begin(this);
+    int len = painter.fontMetrics().width( tmpSize);
+    int hei =painter.fontMetrics().height( );
+    painter.end();
+    size->setGeometry(x+3,3,len+2, hei+2 ) ;
+    size->setBackgroundColor( yellow );
+    size->setAlignment(Qt::AlignVCenter);
+    size->setText(tmpSize);
+
   }
   else
   {
@@ -2262,6 +2383,8 @@ void KSpreadHBorder::mouseReleaseEvent( QMouseEvent * _ev )
       cl->setWidth( 20, m_pCanvas );
     else
       cl->setWidth( _ev->pos().x() - x, m_pCanvas );
+    delete size;
+    size=0;
   }
 
   m_bSelection = FALSE;
@@ -2382,6 +2505,29 @@ void KSpreadHBorder::mouseMoveEvent( QMouseEvent * _ev )
       m_iResizePos = x + twenty;
     painter.drawLine( m_iResizePos, 0, m_iResizePos, m_pCanvas->height() );
     painter.end();
+    QString tmp2;
+    QString tmpSize;
+    tmpSize=i18n("Width : ");
+    tmpSize+=tmp2.setNum(m_iResizePos-x);
+    painter.begin(this);
+    int len = painter.fontMetrics().width(tmpSize );
+    int hei =painter.fontMetrics().height( );
+    painter.end();
+    if(!size)
+    	{
+    	size=new QLabel(m_pCanvas);
+	size->setGeometry(x+3,3,len+2, hei+2 ) ;
+	size->setBackgroundColor( yellow );
+	size->setAlignment(Qt::AlignVCenter);
+	size->setText(tmpSize);
+    	size->show();
+    	}
+    else
+    	{
+	size->setGeometry(x+3,3,len+2, hei+2 ) ;
+	//size->setAlignment(Qt::AlignVCenter);
+	size->setText(tmpSize);
+    	}
   }
   else if ( m_bSelection )
   {
