@@ -49,10 +49,10 @@
 #include <kscript_parsenode.h>
 
 #define UPDATE_BEGIN bool b_update_begin = m_bDisplayDirtyFlag; m_bDisplayDirtyFlag = true;
-#define UPDATE_END if ( !b_update_begin && m_bDisplayDirtyFlag ) m_pTable->emit_updateCell( this, m_iColumn, m_iRow );
-#define DO_UPDATE m_pTable->emit_updateCell( this, m_iColumn, m_iRow )
+#define UPDATE_END if ( !b_update_begin && m_bDisplayDirtyFlag ) m_pTable->updateCell( this, m_iColumn, m_iRow );
+#define DO_UPDATE m_pTable->updateCell( this, m_iColumn, m_iRow )
 
-char KSpreadCell::decimal_point = '\0';
+QChar KSpreadCell::decimal_point = '\0';
 
 /*****************************************************************************
  *
@@ -142,6 +142,7 @@ void KSpreadCell::copyLayout( int _column, int _row )
     setFloatColor( o->floatColor() );
     setFaktor( o->faktor() );
     setMultiRow( o->multiRow() );
+    setVerticalText( o->verticalText() );
     setStyle( o->style() );
 
     KSpreadConditional *tmpCondition;
@@ -172,12 +173,14 @@ void KSpreadCell::copyLayout( int _column, int _row )
   	tmpCondition->fontcond=o->getThirdCondition(0)->fontcond;
   	tmpCondition->m_cond=o->getThirdCondition(0)->m_cond;
     }
+    setComment(o->getComment());
 }
 
 void KSpreadCell::copyAll( KSpreadCell *cell )
 {
+    ASSERT( !isDefault() ); // trouble ahead...
     copyLayout( cell );
-    setText( cell->text() );
+    setCellText( cell->text() );
     setAction(cell->action() );
 
     if ( m_pPrivate )
@@ -187,68 +190,6 @@ void KSpreadCell::copyAll( KSpreadCell *cell )
 	m_pPrivate = cell->m_pPrivate->copy( this );
 }
 
-/* The old implementation
-void KSpreadCell::copyAll( KSpreadCell *cell)
-{
-    setText(cell->text());
-    setAlign( cell->align() );
-    setAlignY( cell->alignY());
-    setTextFont( cell->textFont() );
-    setTextColor( cell->textColor() );
-    setBgColor( cell->bgColor( ) );
-  //When you use column() and row() it don't work
-
-  //setLeftBorderWidth( cell->leftBorderWidth( ) );
-  //setLeftBorderStyle( cell->leftBorderStyle(  ) );
-  //setLeftBorderColor( cell->leftBorderColor(  ) );
- // setTopBorderWidth( cell->topBorderWidth(  ) );
-  //setTopBorderStyle( cell->topBorderStyle(  ) );
-  //setTopBorderColor( cell->topBorderColor(  ) );
-  //setBottomBorderWidth( cell->bottomBorderWidth( ) );
-  //setBottomBorderStyle( cell->bottomBorderStyle(  ) );
-  //setBottomBorderColor( cell->bottomBorderColor( ) );
-  //setRightBorderWidth( cell->rightBorderWidth( ) );
-  //setRightBorderStyle( cell->rightBorderStyle( ) );
-  //setRightBorderColor( cell->rightBorderColor(  ) );
-  setPrecision( cell->precision() );
-  setPrefix( cell->prefix() );
-  setPostfix( cell->postfix() );
-  setFloatFormat( cell->floatFormat() );
-  setFloatColor( cell->floatColor() );
-  setFaktor( cell->faktor() );
-  setMultiRow( cell->multiRow() );
-  KSpreadConditional *tmpCondition=0;
-  //tmpCondition=o->getFirstCondition(0);
-  if(cell->getFirstCondition(0)!=0)
- {
-  	tmpCondition=getFirstCondition();
-  	tmpCondition->val1=cell->getFirstCondition(0)->val1;
-  	tmpCondition->val2=cell->getFirstCondition(0)->val2;
-  	tmpCondition->colorcond=cell->getFirstCondition(0)->colorcond;
-  	tmpCondition->fontcond=cell->getFirstCondition(0)->fontcond;
-  	tmpCondition->m_cond=cell->getFirstCondition(0)->m_cond;
-	}
-  if(cell->getSecondCondition(0)!=0)
-    	{
-  	tmpCondition=getSecondCondition();
-  	tmpCondition->val1=cell->getSecondCondition(0)->val1;
-  	tmpCondition->val2=cell->getSecondCondition(0)->val2;
-  	tmpCondition->colorcond=cell->getSecondCondition(0)->colorcond;
-  	tmpCondition->fontcond=cell->getSecondCondition(0)->fontcond;
-  	tmpCondition->m_cond=cell->getSecondCondition(0)->m_cond;
-	}
-  if(cell->getThirdCondition(0)!=0)
-    	{
-  	tmpCondition=getThirdCondition();
-  	tmpCondition->val1=cell->getThirdCondition(0)->val1;
-  	tmpCondition->val2=cell->getThirdCondition(0)->val2;
-  	tmpCondition->colorcond=cell->getThirdCondition(0)->colorcond;
-  	tmpCondition->fontcond=cell->getThirdCondition(0)->fontcond;
-  	tmpCondition->m_cond=cell->getThirdCondition(0)->m_cond;
-	}
-
-}
-*/
 
 void KSpreadCell::defaultStyle()
 {
@@ -279,7 +220,7 @@ void KSpreadCell::defaultStyle()
   setTextColor( Qt::black );
   setBgColor( Qt::white );
   setFaktor( 1 );
-  setPrecision( 0 );
+  setPrecision( -1 );
   setPostfix( "" );
   setPrefix( "" );
   if(m_firstCondition!=0)
@@ -296,6 +237,8 @@ void KSpreadCell::defaultStyle()
 
   m_conditionIsTrue=false;
   m_numberOfCond=-1;
+  m_strComment="";
+  m_bVerticalText=false;
 }
 
 void KSpreadCell::forceExtraCells( int _col, int _row, int _x, int _y )
@@ -350,7 +293,7 @@ void KSpreadCell::setLayoutDirtyFlag()
     }
 }
 
-bool KSpreadCell::isEmpty()
+bool KSpreadCell::isEmpty() const
 {
   if ( isDefault() )
 	return TRUE;
@@ -871,12 +814,10 @@ void KSpreadCell::makeLayout( QPainter &_painter, int _col, int _row )
     // First get some locale information
     if (!decimal_point)
     { // (decimal_point is static)
-      decimal_point = KGlobal::locale()->decimalSymbol()[0].latin1();
-      // Hmm we should use QChar here and QString a lot more around
-      // here... (David)
-      kdDebug(36001) << "decimal_point is '" << decimal_point << "'" << endl;
+      decimal_point = KGlobal::locale()->decimalSymbol()[0];
+      kdDebug(36001) << "decimal_point is '" << decimal_point.latin1() << "'" << endl;
       // HACK
-      if ( decimal_point == 0 )
+      if ( decimal_point.isNull() )
 	  decimal_point = '.';
     }
 
@@ -892,7 +833,7 @@ void KSpreadCell::makeLayout( QPainter &_painter, int _col, int _row )
     // the zeros later. Is 8 ok ?
     int p = (m_iPrecision == -1) ? 8 : m_iPrecision;
     QString localizedNumber = KGlobal::locale()->formatNumber(v, p);
-    kdDebug(36001) << "LOCALIZED NUMBER is " << localizedNumber.local8Bit() << endl;
+    //kdDebug(36001) << "LOCALIZED NUMBER is " << localizedNumber.local8Bit() << endl;
 
 
 
@@ -902,18 +843,18 @@ void KSpreadCell::makeLayout( QPainter &_painter, int _col, int _row )
     if ( m_iPrecision == -1 && localizedNumber.find(decimal_point) >= 0 )
     {
       int i = localizedNumber.length();
-      bool bend = FALSE;
-      while ( !bend && i > 0 )
+      bool bFinished = FALSE;
+      while ( !bFinished && i > 0 )
       {
-	if ( localizedNumber[ i - 1 ] == '0' )
+	QChar ch = localizedNumber[ i - 1 ];
+        if ( ch == '0' )
 	  localizedNumber.truncate( --i );
-	else if ( localizedNumber[ i - 1 ] == decimal_point )
-	{
-	  bend = TRUE;
-	  localizedNumber.truncate( --i );
-	}
 	else
-	  bend = TRUE;
+        {
+	  bFinished = TRUE;
+          if ( ch == decimal_point )
+            localizedNumber.truncate( --i );
+        }
       }
     }
 
@@ -932,7 +873,7 @@ void KSpreadCell::makeLayout( QPainter &_painter, int _col, int _row )
     	{
     	KSpreadConditional *tmpCondition=0;
 	switch(m_numberOfCond)
-		{	
+		{
 		case 0:
 			tmpCondition=m_firstCondition;
 			break;
@@ -943,7 +884,7 @@ void KSpreadCell::makeLayout( QPainter &_painter, int _col, int _row )
 			tmpCondition=m_thirdCondition;
 			break;
 		}
-	
+
 	m_textPen.setColor(tmpCondition->colorcond);
  	}
     else
@@ -963,7 +904,7 @@ void KSpreadCell::makeLayout( QPainter &_painter, int _col, int _row )
         {
         KSpreadConditional *tmpCondition=0;
         switch(m_numberOfCond)
-		{	
+		{
 		case 0:
 			tmpCondition=m_firstCondition;
 			break;
@@ -980,8 +921,16 @@ void KSpreadCell::makeLayout( QPainter &_painter, int _col, int _row )
         _painter.setFont( m_textFont );
 
   QFontMetrics fm = _painter.fontMetrics();
-  m_iOutTextWidth = fm.width( m_strOutText );
-  m_iOutTextHeight = fm.ascent() + fm.descent();
+  if(!m_bVerticalText)
+        {
+        m_iOutTextWidth = fm.width( m_strOutText );
+        m_iOutTextHeight = fm.ascent() + fm.descent();
+        }
+  else
+        {
+        m_iOutTextWidth = fm.width( m_strOutText.at(0));
+        m_iOutTextHeight = (fm.ascent() + fm.descent())*(m_strOutText.length());
+        }
 
   // Calculate the size of the cell
   RowLayout *rl = m_pTable->rowLayout( m_iRow );
@@ -1156,16 +1105,30 @@ void KSpreadCell::makeLayout( QPainter &_painter, int _col, int _row )
 
   switch( m_eAlignY )
   {
-  case KSpreadCell::Top:
-    m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE+ fm.ascent();
-    break;
-  case KSpreadCell::Bottom:
-    m_iTextY = h - BORDER_SPACE - bottomBorderWidth( _col, _row );
-    break;
-  case KSpreadCell::Middle:
-    m_iTextY = ( h - m_iOutTextHeight ) / 2 + fm.ascent();
-    break;
+        case KSpreadCell::Top:
+                m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE+ fm.ascent();
+                break;
+        case KSpreadCell::Bottom:
+                if(!m_bVerticalText)
+                        m_iTextY = h - BORDER_SPACE - bottomBorderWidth( _col, _row );
+                else
+                        //if((h - BORDER_SPACE - m_iOutTextHeight- bottomBorderWidth( _col, _row ))>0)
+                        if((h - m_iOutTextHeight)>0)
+                                m_iTextY = h - BORDER_SPACE - m_iOutTextHeight- bottomBorderWidth( _col, _row );
+                        else
+                                m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE +m_fmAscent;
+                break;
+        case KSpreadCell::Middle:
+                if(!m_bVerticalText)
+                        m_iTextY = ( h - m_iOutTextHeight ) / 2 +m_fmAscent;
+                else
+                        if(( h - m_iOutTextHeight )>0)
+                                m_iTextY = ( h - m_iOutTextHeight ) / 2 +m_fmAscent;
+                        else
+                                m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE +m_fmAscent;
+                break;
   }
+
   // Vertical alignment
   //m_iTextY = ( h - m_iOutTextHeight ) / 2 + fm.ascent();
   m_fmAscent=fm.ascent();
@@ -1246,7 +1209,7 @@ if(m_bValue && !m_pTable->getShowFormular())
 for(int i=0;i<3;i++)
 {
 switch(i)
-	{	
+	{
 	case 0:
 		tmpCondition=m_firstCondition;
 		break;
@@ -1345,17 +1308,30 @@ ColumnLayout *cl = m_pTable->columnLayout( _col );
 int w = cl->width();
 int h = rl->height();
 switch( m_eAlignY )
-  {
-  case KSpreadCell::Top:
-    m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE +m_fmAscent;
-    break;
-  case KSpreadCell::Bottom:
-    m_iTextY = h - BORDER_SPACE - bottomBorderWidth( _col, _row );
-    break;
-  case KSpreadCell::Middle:
-    m_iTextY = ( h - m_iOutTextHeight ) / 2 +m_fmAscent;
-    break;
-  }
+{
+        case KSpreadCell::Top:
+                m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE +m_fmAscent;
+                break;
+        case KSpreadCell::Bottom:
+                if(!m_bVerticalText)
+                        m_iTextY = h - BORDER_SPACE - bottomBorderWidth( _col, _row );
+                else
+                        if((h - BORDER_SPACE - m_iOutTextHeight- bottomBorderWidth( _col, _row ))>0)
+                                m_iTextY = h - BORDER_SPACE - m_iOutTextHeight- bottomBorderWidth( _col, _row );
+                        else
+                                m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE +m_fmAscent;
+                break;
+        case KSpreadCell::Middle:
+                if(!m_bVerticalText)
+                        m_iTextY = ( h - m_iOutTextHeight ) / 2 +m_fmAscent;
+                else
+                        if(( h - m_iOutTextHeight )>0)
+                                m_iTextY = ( h - m_iOutTextHeight ) / 2 +m_fmAscent;
+                        else
+                                m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE +m_fmAscent;
+                break;
+}
+
 if ( a == KSpreadCell::Undefined )
   {
     if ( m_bValue )
@@ -1382,19 +1358,14 @@ switch( a )
 
 void KSpreadCell::conditionAlign(QPainter &_paint,int _col,int _row)
 {
-int a = m_eAlign;
-RowLayout *rl = m_pTable->rowLayout( _row );
-ColumnLayout *cl = m_pTable->columnLayout( _col );
 
-int w = cl->width();
-int h = rl->height();
 KSpreadConditional *tmpCondition=0;
 
 
 if(m_conditionIsTrue && !m_pTable->getShowFormular())
         {
         switch(m_numberOfCond)
-		{	
+		{
 		case 0:
 			tmpCondition=m_firstCondition;
 			break;
@@ -1409,47 +1380,23 @@ if(m_conditionIsTrue && !m_pTable->getShowFormular())
 	}
 else
 	{
-	_paint.setFont( m_textFont );	
+	_paint.setFont( m_textFont );
 	}
 QFontMetrics fm = _paint.fontMetrics();
-m_iOutTextWidth = fm.width( m_strOutText );
-m_iOutTextHeight = fm.ascent() + fm.descent();
+if(!m_bVerticalText)
+        {
+        m_iOutTextWidth = fm.width( m_strOutText );
+        m_iOutTextHeight = fm.ascent() + fm.descent();
+        }
+  else
+        {
+        m_iOutTextWidth = fm.width( m_strOutText.at(0));
+        m_iOutTextHeight = (fm.ascent() + fm.descent())*(m_strOutText.length());
+        }
 m_fmAscent=fm.ascent();
 
-switch( m_eAlignY )
-  {
-  case KSpreadCell::Top:
-    m_iTextY = topBorderWidth( _col, _row) + BORDER_SPACE +m_fmAscent;
-    break;
-  case KSpreadCell::Bottom:
-    m_iTextY = h - BORDER_SPACE - bottomBorderWidth( _col, _row );
-    break;
-  case KSpreadCell::Middle:
-    m_iTextY = ( h - m_iOutTextHeight ) / 2 +m_fmAscent;
-    break;
-  }
-if ( a == KSpreadCell::Undefined )
-  {
-    if ( m_bValue )
-      a = KSpreadCell::Right;
-    else
-      a = KSpreadCell::Left;
-  }
-if(m_pTable->getShowFormular())
-      a = KSpreadCell::Left;
+offsetAlign(_col,_row);
 
-switch( a )
-  {
-  case KSpreadCell::Left:
-    m_iTextX = leftBorderWidth( _col, _row) + BORDER_SPACE;
-    break;
-  case KSpreadCell::Right:
-    m_iTextX = w - BORDER_SPACE - m_iOutTextWidth - rightBorderWidth( _col, _row );
-    break;
-  case KSpreadCell::Center:
-    m_iTextX = ( w - m_iOutTextWidth ) / 2;
-    break;
-  }
 }
 
 
@@ -1632,7 +1579,7 @@ bool KSpreadCell::calc( bool _makedepend )
 {
   if ( m_bProgressFlag )
   {
-    kdError(36001) << "ERROR: Circle" << endl;
+    kdError(36002) << "ERROR: Circle" << endl;
     m_bError = true;
     m_bValue = false;
     m_bBool = false;
@@ -1653,17 +1600,16 @@ bool KSpreadCell::calc( bool _makedepend )
   if ( !m_bCalcDirtyFlag )
     return true;
 
-  kdDebug(36001) << "CALC r=" << m_iRow << " c=" << m_iColumn << endl;
   m_bLayoutDirtyFlag= true;
   m_bProgressFlag = true;
   m_bCalcDirtyFlag = false;
   if ( _makedepend )
   {
+    kdDebug(36002) << util_cellName( m_iColumn, m_iRow ) << " calc() Looking into dependencies..." << endl;
     KSpreadDepend *dep;
     for ( dep = m_lstDepends.first(); dep != 0L; dep = m_lstDepends.next() )
     {
-      bool ok;
-
+      // Dependency to a rectangular area
       if ( dep->m_iColumn2 != -1 )
       {
 	int left = dep->m_iColumn < dep->m_iColumn2 ? dep->m_iColumn : dep->m_iColumn2;
@@ -1676,8 +1622,7 @@ bool KSpreadCell::calc( bool _makedepend )
 	    KSpreadCell *cell = dep->m_pTable->cellAt( x, y );
 	    if ( cell == 0L )
 	      return false;
-	    ok = cell->calc( _makedepend );
-	    if ( !ok )
+	    if ( cell->calc( _makedepend ) )
 	    {
 	      m_strFormularOut = "####";
 	      m_bValue = false;
@@ -1694,13 +1639,12 @@ bool KSpreadCell::calc( bool _makedepend )
 	    }
 	  }
       }
-      else
+      else // Dependency to a single cell
       {
 	KSpreadCell *cell = dep->m_pTable->cellAt( dep->m_iColumn, dep->m_iRow );
 	if ( cell == 0L )
 	  return false;
-	ok = cell->calc( _makedepend );
-	if ( !ok )
+	if ( !cell->calc( _makedepend ) )
 	{
 	  m_bError = true;
 	  m_strFormularOut = "####";
@@ -1719,6 +1663,7 @@ bool KSpreadCell::calc( bool _makedepend )
       }
     }
   }
+  kdDebug(36002) << util_cellName( m_iColumn, m_iRow ) << " calc() Now calculating." << endl;
 
   KSContext& context = m_pTable->doc()->context();
   if ( !m_pCode || !m_pTable->doc()->interpreter()->evaluate( context, m_pCode, m_pTable ) )
@@ -1771,7 +1716,8 @@ bool KSpreadCell::calc( bool _makedepend )
     m_bValue = false;
     m_bBool = true;
     m_dValue = context.value()->boolValue() ? 1.0 : 0.0;
-    m_strFormularOut = context.value()->boolValue() ? "True" : "False";
+    // (David): i18n'ed True and False - hope it's ok
+    m_strFormularOut = context.value()->boolValue() ? i18n("True") : i18n("False");
   }
   else
   {
@@ -1867,7 +1813,7 @@ void KSpreadCell::paintEvent( KSpreadCanvas *_canvas, const QRect& _rect, QPaint
   	{
   	if(!table()->getShowGrid())
   		{
-  		_painter.setPen(Qt::NoPen);	
+  		_painter.setPen(Qt::NoPen);
   		}
   	else
   		{
@@ -1889,7 +1835,7 @@ void KSpreadCell::paintEvent( KSpreadCanvas *_canvas, const QRect& _rect, QPaint
   	{
     	if(!table()->getShowGrid())
   		{
-  		_painter.setPen(Qt::NoPen);	
+  		_painter.setPen(Qt::NoPen);
   		}
   	else
   		{
@@ -1918,7 +1864,16 @@ void KSpreadCell::paintEvent( KSpreadCanvas *_canvas, const QRect& _rect, QPaint
     _painter.setBrush(m_backGroundBrush);
     _painter.drawRect( _tx + left, _ty + top, w-left-BORDER_SPACE, h - top - BORDER_SPACE);
     }
-
+  if( !m_strComment.isEmpty())
+    {
+    QPointArray point( 3 );
+    point.setPoint( 0,_tx+w-10, _ty + dy );
+    point.setPoint( 1, _tx+w,_ty + dy);
+    point.setPoint( 2,_tx+w,_ty + dy +10 );
+    _painter.setBrush( QBrush(Qt::red  ) );
+    _painter.setPen( Qt::NoPen );
+    _painter.drawPolygon( point );
+    }
   static QColorGroup g( Qt::black, Qt::white, Qt::white, Qt::darkGray, Qt::lightGray, Qt::black, Qt::black );
   static QBrush fill( Qt::lightGray );
   /**
@@ -1993,7 +1948,7 @@ void KSpreadCell::paintEvent( KSpreadCanvas *_canvas, const QRect& _rect, QPaint
         {
         KSpreadConditional *tmpCondition=0;
         switch(m_numberOfCond)
-	{	
+	{
 	case 0:
 		tmpCondition=m_firstCondition;
 		break;
@@ -2014,9 +1969,9 @@ void KSpreadCell::paintEvent( KSpreadCanvas *_canvas, const QRect& _rect, QPaint
 	}
     //_painter.setFont( m_textFont );
     conditionAlign(_painter,_col,_row);
-    if ( !m_bMultiRow )
+    if ( !m_bMultiRow && !m_bVerticalText)
       _painter.drawText( _tx + m_iTextX, _ty + m_iTextY, m_strOutText );
-    else
+    else if( m_bMultiRow && !m_bVerticalText)
     {
       QString t;
       int i;
@@ -2044,8 +1999,8 @@ void KSpreadCell::paintEvent( KSpreadCanvas *_canvas, const QRect& _rect, QPaint
 	    a = KSpreadCell::Left;
 	}
 	if(m_pTable->getShowFormular())
-	    a = KSpreadCell::Left;	
-	
+	    a = KSpreadCell::Left;
+
 	switch( a )
 	{
 	case KSpreadCell::Left:
@@ -2064,6 +2019,48 @@ void KSpreadCell::paintEvent( KSpreadCanvas *_canvas, const QRect& _rect, QPaint
       }
       while ( i != -1 );
     }
+    else if( m_bVerticalText)
+    {
+      QString t;
+      int i=0;
+      int dy = 0;
+      int dx = 0;
+      int j=0;
+      QFontMetrics fm = _painter.fontMetrics();
+      do
+      {
+        i=m_strOutText.length();
+        t=m_strOutText.at(j);
+	int a = m_eAlign;
+	if ( a == KSpreadCell::Undefined )
+	{
+	  if ( m_bValue )
+	    a = KSpreadCell::Right;
+	  else
+	    a = KSpreadCell::Left;
+	}
+	if(m_pTable->getShowFormular())
+	    a = KSpreadCell::Left;
+
+	switch( a )
+	{
+	case KSpreadCell::Left:
+	  m_iTextX = leftBorderWidth( _col, _row) + BORDER_SPACE;
+	  break;
+	case KSpreadCell::Right:
+	  m_iTextX = w - BORDER_SPACE - fm.width( t )
+	    - rightBorderWidth( _col, _row );
+	  break;
+	case KSpreadCell::Center:
+	  m_iTextX = ( w - fm.width( t ) ) / 2;
+	}
+
+	_painter.drawText( _tx + m_iTextX + dx, _ty + m_iTextY + dy, t );
+	dy += fm.descent() + fm.ascent();
+        j++;
+      }
+      while ( j != i );
+    }
   }
 
   if ( m_pTable->isShowPageBorders() )
@@ -2166,7 +2163,7 @@ void KSpreadCell::print( QPainter &_painter, int _tx, int _ty, int _col, int _ro
       	{
         KSpreadConditional *tmpCondition=0;
         switch(m_numberOfCond)
-		{	
+		{
 		case 0:
 			tmpCondition=m_firstCondition;
 			break;
@@ -2177,7 +2174,7 @@ void KSpreadCell::print( QPainter &_painter, int _tx, int _ty, int _col, int _ro
 			tmpCondition=m_thirdCondition;
 			break;
 		}
-	
+
         _painter.setFont( tmpCondition->fontcond );
       	}
       else
@@ -2430,7 +2427,7 @@ Qt::PenStyle KSpreadCell::rightBorderStyle( int _col, int _row )
     {
 	RowLayout *rl = m_pTable->rowLayout( _row );
 	ColumnLayout *cl = m_pTable->columnLayout( _col + 1 );
-	
+
 	if ( rl->time() > cl->time() )
 	    return rl->leftBorderStyle();
 	else
@@ -2464,7 +2461,7 @@ Qt::PenStyle KSpreadCell::fallDiagonalStyle( int _col, int _row )
     {
 	RowLayout *rl = m_pTable->rowLayout( _row );
 	ColumnLayout *cl = m_pTable->columnLayout( _col );
-	
+
 	if ( rl->time() > cl->time() )
 	    return rl->fallDiagonalStyle();
 	else
@@ -2630,9 +2627,12 @@ void KSpreadCell::incPrecision()
     int pos = m_strOutText.find(decimal_point);
     if ( pos == -1 )
       m_iPrecision = 1;
-    m_iPrecision = m_strOutText.length() - pos;
-    if ( m_iPrecision < 0 )
-      m_iPrecision = 0;
+    else
+    {
+      m_iPrecision = m_strOutText.length() - pos;
+      if ( m_iPrecision < 0 )
+        m_iPrecision = 0;
+    }
     m_bLayoutDirtyFlag = TRUE;
   }
   else if ( m_iPrecision < 10 )
@@ -2676,21 +2676,13 @@ void KSpreadCell::setPostfix( const char * _postfix )
   m_bLayoutDirtyFlag= TRUE;
 }
 
-/*
-void KSpreadCell::initAfterLoading()
-{
-    if ( text.isNull() )
-	return;
-    setText( text.data() );
-}
-*/
-
-void KSpreadCell::setText( const QString& _text )
+void KSpreadCell::setCellText( const QString& _text, bool updateDepends )
 {
   m_bError = false;
   m_strText = _text;
 
-  m_lstDepends.clear();
+  if (updateDepends)
+    m_lstDepends.clear();
 
   // Free all content data
   if ( m_pQML )
@@ -2713,7 +2705,7 @@ void KSpreadCell::setText( const QString& _text )
 
     if ( !m_pTable->isLoading() )
 	if ( !makeFormular() )
-	    kdError(36001) << "ERROR: Syntax ERROR" << endl;
+	    kdError(36002) << "ERROR: Syntax ERROR" << endl;
     // A Hack!!!! For testing only
     // QString ret = encodeFormular( column, row );
     // decodeFormular( ret, column, row );
@@ -2774,9 +2766,7 @@ void KSpreadCell::setText( const QString& _text )
       // m_bLayoutDirtyFlag = true;
   }
 
-  // Do not update formulas and stuff here
-  // if we are still loading
-  if ( !m_pTable->isLoading() )
+  if ( updateDepends )
       update();
 }
 
@@ -2810,11 +2800,12 @@ void KSpreadCell::setValue( double _d )
 
 void KSpreadCell::update()
 {
+    kdDebug(36002) << util_cellName( m_iColumn, m_iRow ) << " update" << endl;
     if ( m_pObscuringCell )
     {
 	m_pObscuringCell->setLayoutDirtyFlag();
 	m_pObscuringCell->setDisplayDirtyFlag();
-	m_pTable->emit_updateCell( m_pObscuringCell, m_pObscuringCell->column(), m_pObscuringCell->row() );
+	m_pTable->updateCell( m_pObscuringCell, m_pObscuringCell->column(), m_pObscuringCell->row() );
     }
 
     bool b_update_begin = m_bDisplayDirtyFlag;
@@ -2823,11 +2814,12 @@ void KSpreadCell::update()
     updateDepending();
 
     if ( !b_update_begin && m_bDisplayDirtyFlag )
-	m_pTable->emit_updateCell( this, m_iColumn, m_iRow );
+	m_pTable->updateCell( this, m_iColumn, m_iRow );
 }
 
 void KSpreadCell::updateDepending()
 {
+    kdDebug(36002) << util_cellName( m_iColumn, m_iRow ) << " updateDepending" << endl;
     // Every cell that references us must set its calc dirty flag
     QListIterator<KSpreadTable> it( m_pTable->map()->tableList() );
     for( ; it.current(); ++it )
@@ -2846,6 +2838,7 @@ void KSpreadCell::updateDepending()
 	for ( ; it4.current(); ++it4 )
 	    it4.current()->calc( TRUE );
     }
+    kdDebug(36002) << util_cellName( m_iColumn, m_iRow ) << " updateDepending done" << endl;
 
     // Update a chart for example if it depends on this cell.
     if ( m_iRow != 0 && m_iColumn != 0 )
@@ -3068,7 +3061,8 @@ QDomElement KSpreadCell::save( QDomDocument& doc, int _x_offset, int _y_offset )
     format.setAttribute( "multirow", "yes" );
   if ( style() )
       format.setAttribute( "style", (int)style() );
-
+  if ( verticalText() )
+      format.setAttribute( "verticaltext", "yes" );
   if ( isForceExtraCells() )
   {
     format.setAttribute( "colspan", extraXCells() );
@@ -3093,6 +3087,12 @@ QDomElement KSpreadCell::save( QDomDocument& doc, int _x_offset, int _y_offset )
   	underline.setAttribute( "val",(int)textFontUnderline());
   	format.appendChild( underline );
   	}
+  if ( textFontStrike())
+  	{
+  	QDomElement strike = doc.createElement( "strike" );
+  	strike.setAttribute( "val",(int)textFontStrike());
+  	format.appendChild( strike );
+  	}
   if ( m_textPen != m_pTable->defaultCell()->textPen() )
     {
     if(m_conditionIsTrue)
@@ -3161,6 +3161,12 @@ QDomElement KSpreadCell::save( QDomDocument& doc, int _x_offset, int _y_offset )
   		}
   	cell.appendChild( condition );
   	}
+  if ( !m_strComment.isEmpty() )
+        {
+        QDomElement comment = doc.createElement( "comment" );
+        comment.appendChild( doc.createCDATASection( m_strComment ) );
+        cell.appendChild( comment );
+        }
   if ( !m_strText.isEmpty() )
   {
     if ( isFormular() )
@@ -3220,7 +3226,7 @@ bool KSpreadCell::load( const QDomElement& cell, int _xshift, int _yshift, Paste
 	    // Validation
 	    if ( (unsigned int)a < 1 || (unsigned int)a > 4 )
 	    {
-		kdDebug(36001) << "Value of of range Cell::align=" << (unsigned int)a << endl;
+		kdDebug(36001) << "Value out of range Cell::align=" << (unsigned int)a << endl;
 		return false;
 	    }
 	    // Assignment
@@ -3234,7 +3240,7 @@ bool KSpreadCell::load( const QDomElement& cell, int _xshift, int _yshift, Paste
 	    // Validation
 	    if ( (unsigned int)a < 1 || (unsigned int)a > 4 )
 	    {
-		kdDebug(36001) << "Value of of range Cell::alignY=" << (unsigned int)a << endl;
+		kdDebug(36001) << "Value out of range Cell::alignY=" << (unsigned int)a << endl;
 		return false;
 	    }
 	    // Assignment
@@ -3244,6 +3250,8 @@ bool KSpreadCell::load( const QDomElement& cell, int _xshift, int _yshift, Paste
 	    setBgColor( QColor( f.attribute( "bgcolor" ) ) );
 	if ( f.hasAttribute( "multirow" ) )
 	    setMultiRow( true );
+        if ( f.hasAttribute( "verticaltext" ) )
+	    setVerticalText( true );
 	if ( f.hasAttribute( "colspan" ) )
         {
 	    int i = f.attribute("colspan").toInt( &ok );
@@ -3288,7 +3296,7 @@ bool KSpreadCell::load( const QDomElement& cell, int _xshift, int _yshift, Paste
 	    if ( !ok ) return false;
 	    if ( (unsigned int)a < 1 || (unsigned int)a > 3 )
 	    {
-		kdDebug(36001) << "Value of of range Cell::float=" << (unsigned int)a << endl;
+		kdDebug(36001) << "Value out of range Cell::float=" << (unsigned int)a << endl;
 		return false;
 	    }
 	    // Assignment
@@ -3300,7 +3308,7 @@ bool KSpreadCell::load( const QDomElement& cell, int _xshift, int _yshift, Paste
 	    if ( !ok ) return false;
 	    if ( (unsigned int)a < 1 || (unsigned int)a > 2 )
 	    {
-		kdDebug(36001) << "Value of of range Cell::floatcolor=" << (unsigned int)a << endl;
+		kdDebug(36001) << "Value out of range Cell::floatcolor=" << (unsigned int)a << endl;
 		return false;
 	    }
 	    // Assignment
@@ -3337,6 +3345,16 @@ bool KSpreadCell::load( const QDomElement& cell, int _xshift, int _yshift, Paste
 	    		if ( !ok ) return false;
 	    		}
 
+		}
+        QDomElement strike = f.namedItem( "strike" ).toElement();
+	if ( !strike.isNull() )
+		{
+		if ( strike.hasAttribute( "val" ) )
+        		{
+	    		setTextFontStrike((bool)strike.attribute("val").toInt( &ok ));
+	    		if ( !ok ) return false;
+	    		}
+
 		}
 	QDomElement left = f.namedItem( "left-border" ).toElement();
 	if ( !left.isNull() && pm != NoBorder )
@@ -3467,6 +3485,13 @@ bool KSpreadCell::load( const QDomElement& cell, int _xshift, int _yshift, Paste
   	 	}
 
   	}
+    QDomElement comment = cell.namedItem( "comment" ).toElement();
+    if ( !comment.isNull() && ( pm == ::Normal ||pm == ::Comment || pm == ::NoBorder ))
+        {
+        QString t = comment.text();
+	//t = t.stripWhiteSpace();
+        setComment(t);
+        }
 
     QDomElement text = cell.namedItem( "text" ).toElement();
     if ( !text.isNull() && ( pm == ::Normal || pm == ::Text || pm == ::NoBorder ) )
@@ -3477,7 +3502,8 @@ bool KSpreadCell::load( const QDomElement& cell, int _xshift, int _yshift, Paste
 	if ( t[0] == '=' )
 	    t = decodeFormular( t, m_iColumn, m_iRow );
 
-        setText( pasteOperation( t, m_strText, op ) );
+        // Set the cell's text, and don't calc dependencies yet (see comment for setCellText)
+        setCellText( pasteOperation( t, m_strText, op ), false );
     }
 
     if ( !f.isNull() && f.hasAttribute( "style" ) )
@@ -3626,6 +3652,28 @@ KSpreadCell::~KSpreadCell()
     }
 }
 
+bool KSpreadCell::operator > ( const KSpreadCell & cell ) const
+{
+  if ( isValue() )
+    if ( cell.isValue() )
+      return valueDouble() > cell.valueDouble();
+    else
+      return false; // numbers are always < than texts
+  else
+    return valueString().compare(cell.valueString()) > 0;
+}
+
+bool KSpreadCell::operator < ( const KSpreadCell & cell ) const
+{
+  if ( isValue() )
+    if ( cell.isValue() )
+      return valueDouble() < cell.valueDouble();
+    else
+      return true; // numbers are always < than texts
+  else
+    return valueString().compare(cell.valueString()) < 0;
+}
+
 /***************************************************
  *
  * SelectPrivate
@@ -3657,7 +3705,7 @@ void SelectPrivate::slotItemSelected( int _id )
     m_pCell->checkValue();
     m_pCell->update();
 
-    m_pCell->table()->emit_updateCell( m_pCell, m_pCell->column(), m_pCell->row() );
+    m_pCell->table()->updateCell( m_pCell, m_pCell->column(), m_pCell->row() );
 }
 
 QString SelectPrivate::text() const
