@@ -5,12 +5,12 @@
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
-
+ 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
-
+ 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
@@ -20,27 +20,30 @@
 #ifndef __kspread_dlg_area__
 #define __kspread_dlg_area__
 
-#include <kdialogbase.h>
+#include <qdialog.h>
+#include <qpushbutton.h>
+#include <qlineedit.h>
+#include <qlistbox.h>
+#include <qlabel.h>
 
 class KSpreadView;
-class QPushButton;
-class QLineEdit;
-class QLabel;
 
-class KSpreadarea : public KDialogBase
+class KSpreadarea: public QDialog
 {
   Q_OBJECT
 public:
-  KSpreadarea( KSpreadView * parent, const char * name, const QPoint & _marker );
+  KSpreadarea( KSpreadView* parent, const char* name,const QPoint &_marker );
+
 
 public slots:
   void slotOk();
-  void slotAreaNamechanged( const QString & text);
-
+  void slotClose();
 protected:
-  KSpreadView * m_pView;
-  QLineEdit   * m_areaName;
-  QPoint        m_marker;
+  KSpreadView* m_pView;
+  QLineEdit* areaName;
+  QPushButton* m_pOk;
+  QPushButton* m_pClose;
+  QPoint  marker;
 };
 
 #endif
