@@ -21,28 +21,34 @@
 #ifndef __kspread_dlg_comment__
 #define __kspread_dlg_comment__
 
-#include <kdialogbase.h>
+#include <qdialog.h>
+#include <qpushbutton.h>
+#include <qmultilineedit.h>
+#include <qrect.h>
+
 
 class KSpreadView;
-class KSpreadSheet;
+class KSpreadTable;
 class KSpreadCell;
-class QPushButton;
-class QMultiLineEdit;
 
-class KSpreadComment : public KDialogBase
+class KSpreadcomment : public QDialog
 {
   Q_OBJECT
 public:
-  KSpreadComment( KSpreadView* parent, const char* name,const QPoint &_marker );
+  KSpreadcomment( KSpreadView* parent, const char* name,const QPoint &_marker );
 
 public slots:
   void slotOk();
-  void slotTextChanged();
+  void slotClose();
+
 protected:
 
   KSpreadView* m_pView;
   QMultiLineEdit *multiLine; 
+  QPushButton* m_pOk;
+  QPushButton* m_pClose;
   QPoint  marker;
+
 };
 
 #endif
