@@ -806,7 +806,7 @@ void KSpreadDlgFormula::changeFunction()
 	QString tmp1;
 	if( m_funcName =="cos")
 		{
-		tmp1=i18n("The  cos()  function  returns  the cosine of x,\nwhere x is given in radians.\n");
+		tmp1=i18n("The cos() function returns the cosine of x,\nwhere x is given in radians.\n");
 	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
 	        tmp1+=i18n("Example : \n");
                 tmp1+="cos(0.98) equals 0.5502255.\ncos(0) equals 1.";
@@ -814,7 +814,7 @@ void KSpreadDlgFormula::changeFunction()
 		}
 	else if( m_funcName=="sin")
 		{
-		tmp1=i18n("The  sin()  function  returns  the sine of x,\nwhere x is given in radians.\n");
+		tmp1=i18n("The sin() function returns the sine of x,\nwhere x is given in radians.\n");
 	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
 	        tmp1+=i18n("Example : \n");
                 tmp1+="sin(0.12) equals 0.11971221.\nsin(0) equals 0.";
@@ -822,12 +822,107 @@ void KSpreadDlgFormula::changeFunction()
 		}
 	else if( m_funcName=="tan")
 		{
-		tmp1=i18n("The  tan()  function  returns  the tangent of x,\nwhere x is given in radians.\n");
+		tmp1=i18n("The tan() function returns the tangent of x,\nwhere x is given in radians.\n");
 	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
 	        tmp1+=i18n("Example : \n");
                 tmp1+="tan(0.7) equals 0.84228838.\ntan(0) equals 0.";
                 tmp.help=tmp1;
 		}
+	else if( m_funcName=="acos")
+		{
+		tmp1=i18n("The acos() function returns the arc cosine\n"
+			  "in radians and the value is mathematically\n"
+			  "defined to be between 0 and PI(inclusive).\n");
+	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="acos(0.8) equals 0.6435011.\nacos(0) equals 1.57079633.";
+                tmp.help=tmp1;
+		}
+	else if( m_funcName=="asin")
+		{
+		tmp1=i18n("The asin() function returns the arc sine\n"
+			  "in radians and the value is mathematically\n"
+			  "defined to be between -PI/2 and PI/2 (inclusive).\n");
+	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="asin(0.8) equals 0.92729522.\nasin(0) equals 0.";
+                tmp.help=tmp1;
+		}
+	else if( m_funcName=="atan")
+		{
+		tmp1=i18n("The atan() function returns the arc tangent\n"
+			  "in radians and the value is mathematically\n"
+			  "defined to be between -PI/2 and PI/2 (inclusive).\n");
+	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="atan(0.8) equals 0.67474094.\natan(0) equals 0.";
+                tmp.help=tmp1;
+		}
+	else if( m_funcName=="cosh")
+		{
+		tmp1=i18n("The cosh() function returns the hyperbolic\n"
+			  "cosine of x, which is defined\n"
+			  "mathematically as (exp(x) + exp(-x)) / 2.\n");
+	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="cosh(0.8) equals 1.33743495.\ncosh(0) equals 1.";
+                tmp.help=tmp1;
+		}
+	else if( m_funcName=="sinh")
+		{
+		tmp1=i18n("The  sinh()  function  returns the hyperbolic\nsine of x,which is defined\nmathematically as (exp(x) - exp(-x)) / 2.\n");
+	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="sinh(0.8) equals 0.88810598.\nsinh(0) equals 0.";
+                tmp.help=tmp1;
+		}
+	else if( m_funcName=="tanh")
+		{
+		tmp1=i18n("The tanh() function returns the hyperbolic\n"
+			  "tangent of x, which is defined\n"
+			  "mathematically as sinh(x)/cosh(x).\n");
+	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="tanh(0.8) equals 0.66403677.\ntanh(0) equals 0.";
+                tmp.help=tmp1;
+		}
+	else if( m_funcName=="acosh")
+		{
+		tmp1=i18n("The acosh() function calculates\n"
+			  "the inverse hyperbolic cosine of x;\n"
+			  "that is the value whose hyperbolic\n"
+			  "cosine is x. If x is less\n"
+			  "than 1.0, acosh() returns not-a-number\n"
+			  "(NaN) and errno is set.\n");
+	        tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="acosh(5) equals 2.29243167.\nacosh(0) equals nan.";
+                tmp.help=tmp1;
+		}
+	else if( m_funcName=="asinh")
+		{
+		tmp1=i18n("The asinh() function  calculates\n"
+			  "the inverse hyperbolic sine\n"
+			  "of x; that is the value whose\n"
+			  "hyperbolic sine is x.\n");
+		tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="asinh(0.8) equals 0.73266826.\nasinh(0) equals 0.";
+                tmp.help=tmp1;
+		}
+	else if( m_funcName=="atanh")
+		{
+		tmp1=i18n("The atanh() function calculates\n"
+			  "the inverse hyperbolic tangent of x;\n"
+			  "that is the value whose hyperbolic\n"
+			  "tangent is x. If the absolute value\n"
+			  "of x is greater than 1.0, atanh()\n"
+			  "returns not-a-number (NaN)\n");
+		tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="atanh(0.8) equals 1.09861229.\natanh(0) equals 0.";
+                tmp.help=tmp1;
+		}
 	else
 		tmp.help=i18n("Help");
   	tmp.firstElementType=type_double;
@@ -864,9 +959,52 @@ void KSpreadDlgFormula::changeFunction()
     {
         tmp.nb_param=1;
         tmp.firstElementLabel=i18n("Double");
-        tmp.help=m_funcName+"("+"Double"+")";
-
+	QString tmp1;
         tmp.firstElementType=type_double;
+        if(m_funcName=="ln")
+        	{
+        	tmp1=i18n("The ln() function returns the\n"
+			  "natural logarithm of x.\n");
+		tmp1+=i18n("Syntax : %1(Double)").arg(m_funcName);
+	        tmp1+=i18n("Example : \n");
+                tmp1+="ln(0.8) equals -0.22314355.\nln(0) equals -inf.";
+                tmp.help=tmp1;
+                }
+         else if(m_funcName=="log")
+        	{
+        	tmp1=i18n("The log() function returns\nthe base-10 logarithm of x.\n");
+		tmp1+=i18n("Syntax : %1(Double)").arg(m_funcName);
+	        tmp1+=i18n("Example : \n");
+                tmp1+="log(0.8) equals -0.09691001.\nlog(0) equals -inf.";
+                tmp.help=tmp1;
+                }
+	else if(m_funcName=="sqrt")
+        	{
+        	tmp1=i18n("The sqrt() function returns\n"
+			  "the non-negative square root\n"
+			  "of x. It fails and sets errno to\n"
+			  "EDOM, if x is  negative.\n");
+		tmp1+=i18n("Syntax : %1(Double)").arg(m_funcName);
+	        tmp1+=i18n("Example : \n");
+                tmp1+="sqrt(9) equals 3.\nsqrt(-9) equals nan.";
+                tmp.help=tmp1;
+                }
+	else if(m_funcName=="exp")
+        	{
+        	tmp1=i18n("The exp() function returns\n"
+			  "the value of e (the  base\n"
+			  "of natural logarithms)\n"
+			  "raised to the power of x.\n");
+        	tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
+	        tmp1+=i18n("Example : \n");
+                tmp1+="sqrt(9) equals 3.\nsqrt(-9) equals nan.";
+                tmp.help=tmp1;
+                }
+        else
+        	{
+        	tmp.help=m_funcName+"("+"Double"+")\n";
+        	}
+
     }
     else if (m_funcName=="ISLOGIC"||m_funcName=="ISTEXT"||m_funcName=="ISNUM")
     {
@@ -1138,7 +1276,8 @@ void KSpreadDlgFormula::changeFunction()
         tmp.firstElementLabel=i18n("Double");
         tmp.secondElementLabel=i18n("Double");
 
-        QString tmp1=i18n("The  pow(x,y)  function  returns\nthe value of x raised to the power of y.\n");
+        QString tmp1=i18n("The pow(x,y) function returns\n"
+			  "the value of x raised to the power of y.\n");
         tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double,Double"+")\n";
         tmp1+=i18n("Example : \n");
         tmp1+="pow(1.2,3.4) equals 1.8572.\npow(2,3) equals 8";
@@ -1161,7 +1300,10 @@ void KSpreadDlgFormula::changeFunction()
     {
         tmp.nb_param=1;
         tmp.firstElementLabel=i18n("Double");
-        QString tmp1=i18n("This function return :\n-1 if the number is negative\n0 if the number is null\nand 1 if the number is positive.\n");
+        QString tmp1=i18n("This function return :\n"
+			  "-1 if the number is negative\n"
+			  "0 if the number is null\n"
+			  "and 1 if the number is positive.\n");
         tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double"+")\n";
         tmp1+=i18n("Example : \n");
         tmp1+="sign(5) equals 5.\nsign(-5) equals -1.\nsign(0) equals 0.\n";
@@ -1186,7 +1328,11 @@ void KSpreadDlgFormula::changeFunction()
         tmp.nb_param=2;
         tmp.firstElementLabel=i18n("Double");
         tmp.secondElementLabel=i18n("Double");
-        QString tmp1=i18n("This function calculates the arc tangent\n of the two variables x and y.\nIt is similar to calculating the arc tangent of y/x,\n except that the signs of both arguments\n are used to determine the quadrant of the result.\n");
+        QString tmp1=i18n("This function calculates the arc tangent\n"
+			  "of the two variables x and y.\n"
+			  "It is similar to calculating the arc tangent of y/x,\n"
+			  "except that the signs of both arguments\n"
+			  "are used to determine the quadrant of the result.\n");
 	tmp1+=i18n("Syntax : ") +m_funcName+"("+"Double,Double"+")\n";
 	tmp1+=i18n("Example : \n");
         tmp1+="ATAN2(0.5,1.0) equals 1.107149.\nATAN2(-0.5,2.0) equals 1.815775.";
