@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 1999,2000,2001 Montel Laurent <lmontel@mandrakesoft.com>
+   Copyright (C) 1999 Montel Laurent <montell@club-internet.fr>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,27 +21,36 @@
 #ifndef __kspread_dlg_goto__
 #define __kspread_dlg_goto__
 
-#include <kdialogbase.h>
+#include <qdialog.h>
+#include <qpushbutton.h>
+#include <qlineedit.h>
+
 
 class KSpreadView;
-class KSpreadSheet;
+class KSpreadTable;
 class KSpreadCell;
-class KLineEdit;
 
-class KSpreadGotoDlg : public KDialogBase
+class KSpreadgoto : public QDialog
 {
   Q_OBJECT
 public:
-  KSpreadGotoDlg( KSpreadView* parent, const char* name);
+  KSpreadgoto( KSpreadView* parent, const char* name);
 
 public slots:
   void slotOk();
-  void textChanged ( const QString &_text );
+  void slotClose();
+
 
 
 protected:
   KSpreadView* m_pView;
-  KLineEdit* m_nameCell;
+  
+  QLineEdit* name_cell;
+  QPushButton* m_pOk;
+  QPushButton* m_pClose;
+  QString tabname;
+
+
 };
 
 #endif
