@@ -6,52 +6,55 @@
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
-
+ 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
-
+ 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
-*/
+*/     
 
 #ifndef __kspread_dlg_series__
 #define __kspread_dlg_series__
 
-#include <kdialogbase.h>
+#include <qdialog.h>
+#include <qpushbutton.h>
+#include <qradiobutton.h>
+#include <qcheckbox.h>
+#include <qlineedit.h>
 
 class KSpreadView;
-class KSpreadSheet;
+class KSpreadTable;
 class KSpreadCell;
-class QRadioButton;
-class QCheckBox;
-class KDoubleNumInput;
 
-class KSpreadSeriesDlg : public KDialogBase
+class KSpreadseries : public QDialog
 {
-    Q_OBJECT
+  Q_OBJECT
 public:
+  
+KSpreadseries(KSpreadView* parent, const char* name,const QPoint &_marker);  
 
-    KSpreadSeriesDlg(KSpreadView* parent, const char* name,const QPoint &_marker);
-
-    KSpreadSheet* table;
+KSpreadTable* table;
 
 public slots:
-    void slotOk();
+  void slotOk();
+  void slotClose();
 protected:
-    KSpreadView* m_pView;
-    KDoubleNumInput *start;
-    KDoubleNumInput *end;
-    KDoubleNumInput *step;
-
-    QRadioButton* column;
-    QRadioButton* row;
-    QRadioButton* linear;
-    QRadioButton* geometric;
-    QPoint  marker;
+  KSpreadView* m_pView;
+  QLineEdit* start;
+  QLineEdit* end;
+  QLineEdit* step;
+  QPushButton* m_pOk;
+  QPushButton* m_pClose;
+  QRadioButton* column;
+  QRadioButton* row;
+  QRadioButton* linear;
+  QRadioButton* geometric;
+  QPoint  marker;
 };
 
 #endif
