@@ -63,7 +63,8 @@ KSpreadshow::KSpreadshow( KSpreadView* parent, const char* name )
     	text=*it;
     	list->insertItem(text);
     	}
-
+  if(!list->count())
+  	m_pOk->setEnabled(false);
   connect( m_pOk, SIGNAL( clicked() ), this, SLOT( slotOk() ) );
   connect( m_pClose, SIGNAL( clicked() ), this, SLOT( slotClose() ) );
   connect( list, SIGNAL(doubleClicked(QListBoxItem *)),this,SLOT(slotDoubleClicked(QListBoxItem *)));
