@@ -48,6 +48,7 @@
 #include <kscript_context.h>
 #include <kstddirs.h>
 #include <kdebug.h>
+#include <kconfig.h>
 #include <koTemplateChooseDia.h>
 #include <koFilterManager.h>
 
@@ -113,7 +114,7 @@ KSpreadDoc::KSpreadDoc( QObject* parent, const char* name, bool singleViewMode )
   // Make us scriptable if the document has a name
   if ( name )
       dcopObject();
-  
+
   m_newView = new KAction( i18n("New View"), 0, this, SLOT( newView() ), actionCollection(), "newView" );
 }
 
@@ -126,9 +127,9 @@ bool KSpreadDoc::initDoc()
 					"*.ksp", "KSpread", KoTemplateChooseDia::NoTemplates );
 
     if ( ret == KoTemplateChooseDia::File ) {
-        QString fileName(f);
-	KURL::encode( fileName );
-	return openURL( KURL( fileName ) );
+        KURL url;
+        url.setPath(f);
+	return openURL( url );
     } else if ( ret == KoTemplateChooseDia::Empty ) {
 	KSpreadTable *t = createTable();
 	m_pMap->addTable( t );
@@ -363,9 +364,10 @@ bool KSpreadDoc::loadXML( const QDomDocument& doc, KoStore* )
       return false;
     }
 
-  m_bLoading = false;
-  m_pMap->update();
-  setModified( FALSE );
+  // All this is done in completeLoading...
+  //m_bLoading = false;
+  //m_pMap->update();
+  //setModified( FALSE );
   return true;
 }
 
