@@ -77,6 +77,7 @@ public:
     virtual void setTextFontBold( bool _b ) { m_textFont.setBold( _b ); }
     virtual void setTextFontItalic( bool _i ) { m_textFont.setItalic( _i ); }
     virtual void setTextFontUnderline( bool _i ) { m_textFont.setUnderline( _i ); }
+    virtual void setTextFontStrike( bool _i ) { m_textFont.setStrikeOut( _i ); }
     virtual void setTextFont( const QFont& _f ) { m_textFont = _f; }
     virtual void setTextColor( const QColor & _c ) { m_textPen.setColor( _c ); m_textColor = _c; }
     virtual void setBgColor( const QColor & _c ) { m_bgColor = _c; }
@@ -153,7 +154,7 @@ public:
     virtual bool textFontBold() { return m_textFont.bold(); }
     virtual bool textFontItalic() { return m_textFont.italic(); }
     virtual bool textFontUnderline() { return m_textFont.underline(); }
-
+    virtual bool textFontStrike() { return m_textFont.strikeOut(); }
     virtual Align align() { return m_eAlign; }
 
     virtual AlignY alignY() { return m_eAlignY; }
@@ -177,6 +178,13 @@ public:
     virtual void setTopBorderPen( const QPen& _p ) { m_topBorderPen = _p; m_iTopBorderWidth = _p.width(); }
     virtual void setBackGroundBrush( const QBrush& _p) {m_backGroundBrush= _p;}
 
+
+    virtual void setVerticalText( bool _b ) { m_bVerticalText = _b; }
+    virtual bool verticalText() { return m_bVerticalText; }
+
+    virtual QString getComment() {return m_strComment;}
+    virtual void setComment(QString _comment){ m_strComment=_comment;}
+
     KSpreadTable* table() { return m_pTable; }
 
 protected:
@@ -277,6 +285,10 @@ protected:
      */
     double m_dFaktor;
 
+    bool m_bVerticalText;
+
+    QString m_strComment;
+
     KSpreadTable *m_pTable;
 };
 
