@@ -335,14 +335,15 @@ public:
     /**
      * Recalculates the current table. If you want to recalculate EVERYTHING, then
      * call @ref Table::setCalcDirtyFlag for all tables in the @ref #m_pMap to make
-     * shure that no invalid values in other tables make you trouble.
+     * sure that no invalid values in other tables make you trouble.
      */
     void recalc(bool mdepend=false);
 
     /**
      * Sets the contents of the cell at row,column to text
+     * @param updateDepends set to false to disable updating the dependencies
      */
-    void setText( int row, int column, const QString& text );
+    void setText( int row, int column, const QString& text, bool updateDepends = true );
 
     /**
      * @return the rectangle of the choose selection.
@@ -362,25 +363,33 @@ public:
     void setSelection( const QRect &_rect, KSpreadCanvas *_canvas = 0L );
 
     void setSelectionFont( const QPoint &_marker, const char *_font = 0L, int _size = -1,
-			   signed char _bold = -1, signed char _italic = -1, signed char _underline = -1 );
+			   signed char _bold = -1, signed char _italic = -1, signed char _underline = -1,
+                           signed char _strike = -1 );
     void setSelectionMoneyFormat( const QPoint &_marker,bool b );
     void setSelectionAlign( const QPoint &_marker, KSpreadLayout::Align _align );
     void setSelectionAlignY( const QPoint &_marker, KSpreadLayout::AlignY _alignY );
     void setSelectionPrecision( const QPoint &_marker, int _delta );
     void setSelectionPercent( const QPoint &_marker, bool b );
     void setSelectionMultiRow( const QPoint &_marker, bool enable );
-    
-    /** 
+
+    /**
     * setSelectionSize increase or decrease font size
     */
     void setSelectionSize( const QPoint &_marker,int _size );
 
     /**
-    *change string to upper case if _type equals 1
-    * or change string to lower if _type equals -1
-    */
+     *change string to upper case if _type equals 1
+     * or change string to lower if _type equals -1
+     */
     void setSelectionUpperLower( const QPoint &_marker,int _type );
-    
+
+    void setSelectionfirstLetterUpper( const QPoint &_marker);
+
+    void setSelectionVerticalText( const QPoint &_marker,bool _b);
+
+    void setSelectionComment( const QPoint &_marker,QString _comment);
+    void setSelectionRemoveComment( const QPoint &_marker);
+
     void setSelectionTextColor( const QPoint &_marker, QColor tbColor );
     void setSelectionbgColor( const QPoint &_marker, QColor bg_Color );
     void setSelectionBorderColor( const QPoint &_marker, QColor bd_Color );
@@ -392,13 +401,11 @@ public:
     void paste( const QPoint &_marker, PasteMode=Normal, Operation=OverWrite );
     void defaultSelection(const QPoint &_marker );
 
-    bool replace( const QPoint &_marker,QString _find,QString _replace );
-    void onlyRow( SortingOrder = Increase );
-    void onlyColumn( SortingOrder = Increase );
+    bool replace( const QPoint &_marker,QString _find,QString _replace,bool b_sensitive, bool b_whole );
+    QString replaceText( QString cellText,QString _find,QString _replace,bool b_sensitive, bool b_whole );
     void sortByRow( int ref_row, SortingOrder = Increase );
     void sortByColumn( int ref_column, SortingOrder = Increase );
-    bool isSorting() { return m_sort; }
-    void setSort( bool sort ) { m_sort=sort; }
+    void swapCells( int x1, int y1, int x2, int y2 );
     void setSeries( const QPoint &_marker,int start,int end,int step,Series mode,Series type );
     /**
      * Insert or remove =>move cells
@@ -455,13 +462,15 @@ public:
      */
     void changeNameCellRef2(const QPoint & pos,ChangeRef ref,QString tabname);
 
-    // ############ Naming error
-    bool isHide(){return m_bTableHide;}
-
     /**
-     * change m_tableHide
+     * @return true if this table is hidden
      */
-    void setHide(bool _tableHide){m_bTableHide=_tableHide;}
+    bool isHidden() { return m_bTableHide; }
+    /**
+     * Hides or shows this tables
+     */
+    void setHidden(bool hidden) { m_bTableHide=hidden; }
+
     /**
      * Unselects all selected columns/rows/cells and redraws these cells.
      */
@@ -540,7 +549,7 @@ public:
     /**
      * A convenience function that finds a table by its name.
      */
-    KSpreadTable *findTable( const char *_name );
+    KSpreadTable *findTable( const QString & _name );
 
     /**
      * Used by Undo.
@@ -619,16 +628,19 @@ public:
     static KSpreadTable* find( int _id );
 
     /**
-     * Emits the signal @ref #sig_updateCell and sets the cells @ref KSpreadCell::m_bDisplayDirtyFlag to false.
+     * Calculates the cell if necessary, makes its layout if necessary,
+     * and force redraw.
+     * Then it sets the cell's @ref KSpreadCell::m_bDisplayDirtyFlag to false.
      */
-    void emit_updateCell( KSpreadCell* _cell, int _col, int _row );
+    void updateCell( KSpreadCell* _cell, int _col, int _row );
+
+
     void emit_updateRow( RowLayout *_layout, int _row );
     void emit_updateColumn( ColumnLayout *_layout, int _column );
 
 signals:
     void sig_updateView( KSpreadTable *_table );
     void sig_updateView( KSpreadTable *_table, const QRect& );
-    void sig_updateCell( KSpreadTable *_table, KSpreadCell* _cell, int _col, int _row );
     void sig_unselect( KSpreadTable *_table, const QRect& );
     void sig_updateHBorder( KSpreadTable *_table );
     void sig_updateVBorder( KSpreadTable *_table );
@@ -755,11 +767,6 @@ protected:
     int m_iMaxColumn;
     bool m_bScrollbarUpdates;
 
-    /**
-     * Set to TRUE while sorting.
-     */
-    bool m_sort;
-
     DCOPObject* m_dcop;
     bool m_bTableHide;
 
