@@ -78,6 +78,8 @@
 #include "kspread_dlg_reference.h"
 #include "kspread_dlg_area.h"
 #include "kspread_dlg_resize2.h"
+#include "kspread_dlg_preference.h"
+#include "kspread_dlg_comment.h"
 #include <kscript_scriptmenu.h>
 
 #include "handler.h"
@@ -145,6 +147,7 @@ KSpreadView::KSpreadView( QWidget *_parent, const char *_name, KSpreadDoc* doc )
     m_pPosWidget = new QLabel( m_pToolWidget );
     m_pPosWidget->setAlignment( AlignCenter );
     m_pPosWidget->setFrameStyle( QFrame::WinPanel|QFrame::Sunken );
+
     m_pPosWidget->setMinimumWidth( 100 );
     hbox->addWidget( m_pPosWidget );
     hbox->addSpacing( 6 );
@@ -196,18 +199,21 @@ KSpreadView::KSpreadView( QWidget *_parent, const char *_name, KSpreadDoc* doc )
     // Handler for moving and resizing embedded parts
     (void)new ContainerHandler( this, m_pCanvas );
 
-    m_bold = new KToggleAction( i18n("Bold"), "bold", CTRL + Key_B, actionCollection(), "bold");
+    m_bold = new KToggleAction( i18n("Bold"), "text_bold", CTRL + Key_B, actionCollection(), "bold");
     connect( m_bold, SIGNAL( toggled( bool ) ), this, SLOT( bold( bool ) ) );
-    m_italic = new KToggleAction( i18n("Italic"), "italic", CTRL + Key_I, actionCollection(), "italic");
+    m_italic = new KToggleAction( i18n("Italic"), "text_italic", CTRL + Key_I, actionCollection(), "italic");
     connect( m_italic, SIGNAL( toggled( bool ) ), this, SLOT( italic( bool ) ) );
-    m_underline = new KToggleAction( i18n("Underline"), "underline", CTRL + Key_U, actionCollection(), "underline");
+    m_underline = new KToggleAction( i18n("Underline"), "text_under", CTRL + Key_U, actionCollection(), "underline");
     connect( m_underline, SIGNAL( toggled( bool ) ), this, SLOT( underline( bool ) ) );
 
+    m_strikeOut = new KToggleAction( i18n("Strike out"), "strike_out", 0, actionCollection(), "strikeout");
+    connect( m_strikeOut, SIGNAL( toggled( bool ) ), this, SLOT( strikeOut( bool ) ) );
+
     m_percent = new KToggleAction( i18n("Percent format"), "percent", 0, actionCollection(), "percent");
     connect( m_percent, SIGNAL( toggled( bool ) ), this, SLOT( percent( bool ) ) );
-    m_precplus = new KAction( i18n("Increase precision"), "precplus", 0, this,
+    m_precplus = new KAction( i18n("Increase precision"), "prec_plus", 0, this,
 			      SLOT( precisionPlus() ), actionCollection(), "precplus");
-    m_precminus = new KAction( i18n("Decrease precision"), "precminus", 0, this,
+    m_precminus = new KAction( i18n("Decrease precision"), "prec_minus", 0, this,
 			      SLOT( precisionMinus() ), actionCollection(), "precminus");
     m_money = new KToggleAction( i18n("Money format"), "money", 0, actionCollection(), "money");
     connect( m_money, SIGNAL( toggled( bool ) ), this, SLOT( moneyFormat( bool ) ) );
@@ -238,67 +244,70 @@ KSpreadView::KSpreadView( QWidget *_parent, const char *_name, KSpreadDoc* doc )
     m_copy = KStdAction::copy( this, SLOT( copySelection() ), actionCollection(), "copy" );
     m_paste = KStdAction::paste( this, SLOT( paste() ), actionCollection(), "paste" );
     m_cut = KStdAction::cut( this, SLOT( cutSelection() ), actionCollection(), "cut" );
-    m_specialPaste = new KAction( i18n("Special Paste..."), 0, this, SLOT( specialPaste() ), actionCollection(), "specialPaste" );
-    m_editCell = new KAction( i18n("Edit Cell"), CTRL + Key_E, this, SLOT( editCell() ), actionCollection(), "editCell" );
-    m_delete = new KAction( i18n("Delete"), 0, this, SLOT( deleteSelection() ), actionCollection(), "delete" );
+    m_specialPaste = new KAction( i18n("Special Paste..."), "special_paste",0, this, SLOT( specialPaste() ), actionCollection(), "specialPaste" );
+    m_editCell = new KAction( i18n("Edit Cell"),"cell_edit", CTRL + Key_E, this, SLOT( editCell() ), actionCollection(), "editCell" );
+    m_delete = new KAction( i18n("Delete"),"deletecell", 0, this, SLOT( deleteSelection() ), actionCollection(), "delete" );
     m_clear = new KAction( i18n("Clear"), 0, this, SLOT( clearSelection() ), actionCollection(), "clear" );
     m_adjust = new KAction( i18n("Adjust row and column"), 0, this, SLOT( adjust() ), actionCollection(), "adjust" );
     m_default = new KAction( i18n("Default"), 0, this, SLOT( defaultSelection() ), actionCollection(), "default" );
     m_areaName = new KAction( i18n("Area name"), 0, this, SLOT( setAreaName() ), actionCollection(), "areaname" );
     m_showArea = new KAction( i18n("Show area..."), 0, this, SLOT( showAreaName() ), actionCollection(), "showArea" );
-    m_resizeRow = new KAction( i18n("Resize row..."),"resizerow", 0, this, SLOT( resizeRow() ), actionCollection(), "resizeRow" );
-    m_resizeColumn = new KAction( i18n("Resize column..."),"resizecol", 0, this, SLOT( resizeColumn() ), actionCollection(), "resizeCol" );
-    m_equalizeRow = new KAction( i18n("Equalize row"),"adjustrow", 0, this, SLOT( equalizeRow() ), actionCollection(), "equalizeRow" );
-    m_equalizeColumn = new KAction( i18n("Equalize column"),"adjustcol", 0, this, SLOT( equalizeColumn() ), actionCollection(), "equalizeCol" );
+    m_resizeRow = new KAction( i18n("Resize row..."), "resizerow", 0, this, SLOT( resizeRow() ), actionCollection(), "resizeRow" );
+    m_resizeColumn = new KAction( i18n("Resize column..."), "resizecol", 0, this, SLOT( resizeColumn() ), actionCollection(), "resizeCol" );
+    m_equalizeRow = new KAction( i18n("Equalize row"), "adjustrow", 0, this, SLOT( equalizeRow() ), actionCollection(), "equalizeRow" );
+    m_equalizeColumn = new KAction( i18n("Equalize column"), "adjustcol", 0, this, SLOT( equalizeColumn() ), actionCollection(), "equalizeCol" );
 
-    m_fontSizeUp = new KAction( i18n("Increase font size"),"fontsizeup", 0, this, SLOT( increaseFontSize() ), actionCollection(), "increaseFontSize" );
-    m_fontSizeDown = new KAction( i18n("Decrease font size"),"fontsizedown", 0, this, SLOT( decreaseFontSize() ), actionCollection(), "decreaseFontSize" );
-    m_upper = new KAction( i18n("Upper case"),"upper", 0, this, SLOT( upper() ), actionCollection(), "upper" );
-    m_lower = new KAction( i18n("Lower case"),"lower", 0, this, SLOT( lower() ), actionCollection(), "lower" );
+    m_fontSizeUp = new KAction( i18n("Increase font size"), "fontsizeup", 0, this, SLOT( increaseFontSize() ), actionCollection(), "increaseFontSize" );
+    m_fontSizeDown = new KAction( i18n("Decrease font size"), "fontsizedown", 0, this, SLOT( decreaseFontSize() ), actionCollection(), "decreaseFontSize" );
+    m_upper = new KAction( i18n("Upper case"), "upper", 0, this, SLOT( upper() ), actionCollection(), "upper" );
+    m_lower = new KAction( i18n("Lower case"), "lower", 0, this, SLOT( lower() ), actionCollection(), "lower" );
 
     m_undo = KStdAction::undo( this, SLOT( undo() ), actionCollection(), "undo" );
     m_undo->setEnabled( FALSE );
     m_redo = KStdAction::redo( this, SLOT( redo() ), actionCollection(), "redo" );
     m_redo->setEnabled( FALSE );
     m_paperLayout = new KAction( i18n("Paper Layout..."), 0, this, SLOT( paperLayoutDlg() ), actionCollection(), "paperLayout" );
-    m_insertTable = new KAction( i18n("Insert Table"), 0, this, SLOT( insertTable() ), actionCollection(), "insertTable" );
+    m_insertTable = new KAction( i18n("Insert Table"),"inserttable", 0, this, SLOT( insertTable() ), actionCollection(), "insertTable" );
     m_removeTable = new KAction( i18n("Remove Table"), 0, this, SLOT( removeTable() ), actionCollection(), "removeTable" );
     m_showTable = new KAction(i18n("Show Table"),0 ,this,SLOT( showTable()), actionCollection(), "showTable" );
     m_hideTable = new KAction(i18n("Hide Table"),0 ,this,SLOT( hideTable()), actionCollection(), "hideTable" );
-    m_hideGrid = new KToggleAction( i18n("Hide Grid"), 0, actionCollection(), "hideGrid");
-    connect( m_hideGrid, SIGNAL( toggled( bool ) ), this, SLOT( toggleGrid( bool ) ) );
-    m_showFormular = new KToggleAction( i18n("Show formular"), 0, actionCollection(), "showFormular");
-    connect( m_showFormular, SIGNAL( toggled( bool ) ), this, SLOT( toggleFormular( bool ) ) );
-    m_LcMode = new KToggleAction( i18n("LC mode"), 0, actionCollection(), "LcMode");
-    connect( m_LcMode, SIGNAL( toggled( bool ) ), this, SLOT( toggleLcMode( bool ) ) );
-    m_showColumnNumber = new KToggleAction( i18n("Show column number"), 0, actionCollection(), "columnNumber");
-    connect( m_showColumnNumber, SIGNAL( toggled( bool ) ), this, SLOT( toggleColumnNumber( bool ) ) );
+    m_removeTable = new KAction( i18n("Preference..."), 0, this, SLOT( preference() ), actionCollection(), "preference" );
+    m_firstLetterUpper = new KAction( i18n("Convert first letter to upper case"),"first_letter_upper" ,0, this, SLOT( firstLetterUpper() ), actionCollection(), "firstletterupper" );
+    m_verticalText = new KToggleAction( i18n("Vertical text"),"vertical_text" ,0 ,actionCollection(), "verticaltext" );
+    connect( m_verticalText, SIGNAL( toggled( bool ) ), this, SLOT( verticalText( bool ) ) );
+    m_addModifyComment = new KAction( i18n("Add/modify comment..."),"comment", 0, this, SLOT( addModifyComment() ), actionCollection(), "addmodifycomment" );
+    m_showComment = new KAction( i18n("Show comment"), 0, this, SLOT( showComment() ), actionCollection(), "showcomment" );
+    m_removeComment = new KAction( i18n("Remove comment"),"removecomment", 0, this, SLOT( removeComment() ), actionCollection(), "removecomment" );
     m_editGlobalScripts = new KAction( i18n("Edit Global Scripts..."), 0, this, SLOT( editGlobalScripts() ),
 				       actionCollection(), "editGlobalScripts" );
     m_editLocalScripts = new KAction( i18n("Edit Local Scripts..."), 0, this, SLOT( editLocalScripts() ), actionCollection(), "editLocalScripts" );
     m_reloadScripts = new KAction( i18n("Reload Scripts"), 0, this, SLOT( reloadScripts() ), actionCollection(), "reloadScripts" );
-    m_gotoCell = new KAction( i18n("Goto Cell..."), 0, this, SLOT( gotoCell() ), actionCollection(), "gotoCell" );
+    m_gotoCell = new KAction( i18n("Goto Cell..."),"goto", 0, this, SLOT( gotoCell() ), actionCollection(), "gotoCell" );
     m_showPageBorders = new KToggleAction( i18n("Show page borders"), 0, actionCollection(), "showPageBorders");
     connect( m_showPageBorders, SIGNAL( toggled( bool ) ), this, SLOT( togglePageBorders( bool ) ) );
-    m_replace = new KAction( i18n("Replace..."), 0, this, SLOT( replace() ), actionCollection(), "replace" );
+    m_replace = new KAction( i18n("Find and Replace..."), "find",CTRL + Key_F, this, SLOT( replace() ), actionCollection(), "replace" );
     m_conditional = new KAction( i18n("Relational cell attributes..."), 0, this, SLOT( conditional() ), actionCollection(), "conditional" );
     m_sort = new KAction( i18n("Sort"), 0, this, SLOT( sort() ), actionCollection(), "sort" );
     m_consolidate = new KAction( i18n("Consolidate..."), 0, this, SLOT( consolidate() ), actionCollection(), "consolidate" );
-    //m_help = new KAction( i18n("KSpread Help..."), 0, this, SLOT( help() ), actionCollection(), "help" );
+
     m_multiRow = new KToggleAction( i18n("Multi Row"), "multirow", 0, actionCollection(), "multiRow" );
     connect( m_multiRow, SIGNAL( toggled( bool ) ), this, SLOT( multiRow( bool ) ) );
     m_selectFont = new KFontAction( i18n("Select Font"), 0, actionCollection(), "selectFont" );
     connect( m_selectFont, SIGNAL( activated( const QString& ) ), this, SLOT( fontSelected( const QString& ) ) );
     m_selectFontSize = new KFontSizeAction( i18n("Select Font Size"), 0, actionCollection(), "selectFontSize" );
     connect( m_selectFontSize, SIGNAL( fontSizeChanged( int ) ), this, SLOT( fontSizeSelected( int ) ) );
-    m_deleteColumn = new KAction( i18n("Delete Column"), "colout", 0, this, SLOT( deleteColumn() ),
+    m_deleteColumn = new KAction( i18n("Delete Column"), "delete_table_col", 0, this, SLOT( deleteColumn() ),
 				  actionCollection(), "deleteColumn" );
-    m_deleteRow = new KAction( i18n("Delete Row"), "rowout", 0, this, SLOT( deleteRow() ),
+    m_deleteRow = new KAction( i18n("Delete Row"), "delete_table_row", 0, this, SLOT( deleteRow() ),
 			       actionCollection(), "deleteRow" );
-    m_insertColumn = new KAction( i18n("Insert Column"), "colin", 0, this, SLOT( insertColumn() ),
+    m_insertColumn = new KAction( i18n("Insert Column"), "insert_table_col" , 0, this, SLOT( insertColumn() ),
 				  actionCollection(), "insertColumn" );
-    m_insertRow = new KAction( i18n("Insert Row"), "rowin", 0, this, SLOT( insertRow() ),
+    m_insertRow = new KAction( i18n("Insert Row"), "insert_table_row", 0, this, SLOT( insertRow() ),
 			       actionCollection(), "insertRow" );
+    m_insertCell = new KAction( i18n("Insert Cell"), "insertcell", 0, this, SLOT( slotInsert() ),
+			       actionCollection(), "insertCell" );
+    m_removeCell = new KAction( i18n("Remove Cell"), "removecell", 0, this, SLOT( slotInsert() ),
+			       actionCollection(), "removeCell" );
     m_cellLayout = new KAction( i18n("Cell Layout..."), CTRL + Key_L, this, SLOT( layoutDlg() ),
 			       actionCollection(), "cellLayout" );
     m_formulaPower = new KAction( i18n("Formula Power"), "rsup", 0, this, SLOT( formulaPower() ),
@@ -346,7 +355,7 @@ KSpreadView::KSpreadView( QWidget *_parent, const char *_name, KSpreadDoc* doc )
                         actionCollection(), "insertPart");
     (void) new KAction( i18n("Chart"), "chart", 0, this, SLOT( insertChart() ), actionCollection(), "insertChart" );
 
-    m_autoSum = new KAction( i18n("AutoSum"), "black-sum", 0, this, SLOT( autoSum() ),
+    m_autoSum = new KAction( i18n("AutoSum"), "black_sum", 0, this, SLOT( autoSum() ),
                              actionCollection(), "autoSum" );
     m_sortDec = new KAction( i18n("Sort descreasing"), "sort_decrease", 0, this, SLOT( sortDec() ),
                              actionCollection(), "sortDec" );
@@ -357,13 +366,13 @@ KSpreadView::KSpreadView( QWidget *_parent, const char *_name, KSpreadDoc* doc )
     m_bgColor = new KColorAction( i18n("Background color"), KColorAction::BackgroundColor, 0, this, SLOT( changeBackgroundColor() ),
 			       actionCollection(), "backgroundColor" );
     m_function = new KAction( i18n("Function"), "funct", 0, this, SLOT( funct() ), actionCollection(), "function" );
-    m_borderLeft = new KAction( i18n("Border left"), "borderleft", 0, this, SLOT( borderLeft() ), actionCollection(), "borderLeft" );
-    m_borderRight = new KAction( i18n("Border Right"), "borderright", 0, this, SLOT( borderRight() ), actionCollection(), "borderRight" );
-    m_borderTop = new KAction( i18n("Border Top"), "bordertop", 0, this, SLOT( borderTop() ), actionCollection(), "borderTop" );
-    m_borderBottom = new KAction( i18n("Border Bottom"), "borderbottom", 0, this, SLOT( borderBottom() ), actionCollection(), "borderBottom" );
-    m_borderAll = new KAction( i18n("All borders"), "borderall", 0, this, SLOT( borderAll() ), actionCollection(), "borderAll" );
-    m_borderRemove = new KAction( i18n("Remove Borders"), "borderremove", 0, this, SLOT( borderRemove() ), actionCollection(), "borderRemove" );
-    m_borderOutline = new KAction( i18n("Border Outline"), "borderoutline", 0, this, SLOT( borderOutline() ), actionCollection(), "borderOutline" );
+    m_borderLeft = new KAction( i18n("Border left"), "border_left", 0, this, SLOT( borderLeft() ), actionCollection(), "borderLeft" );
+    m_borderRight = new KAction( i18n("Border Right"), "border_right", 0, this, SLOT( borderRight() ), actionCollection(), "borderRight" );
+    m_borderTop = new KAction( i18n("Border Top"), "border_top", 0, this, SLOT( borderTop() ), actionCollection(), "borderTop" );
+    m_borderBottom = new KAction( i18n("Border Bottom"), "border_bottom", 0, this, SLOT( borderBottom() ), actionCollection(), "borderBottom" );
+    m_borderAll = new KAction( i18n("All borders"), "border_all", 0, this, SLOT( borderAll() ), actionCollection(), "borderAll" );
+    m_borderRemove = new KAction( i18n("Remove Borders"), "border_remove", 0, this, SLOT( borderRemove() ), actionCollection(), "borderRemove" );
+    m_borderOutline = new KAction( i18n("Border Outline"), ("border_outline"), 0, this, SLOT( borderOutline() ), actionCollection(), "borderOutline" );
     m_borderColor = new KColorAction( i18n("Border Color"), KColorAction:: FrameColor, 0, this, SLOT( changeBorderColor() ),
 			       actionCollection(), "borderColor" );
     m_tableFormat = new KAction( i18n("Table Style..."), 0, this, SLOT( tableFormat() ), actionCollection(), "tableFormat" );
@@ -399,16 +408,13 @@ void KSpreadView::initialPosition()
     m_pCanvas->gotoLocation( col, row );
 
     //init toggle button
-    m_hideGrid->setChecked( !m_pTable->getShowGrid() );
     m_showPageBorders->setChecked( m_pTable->isShowPageBorders());
-    m_showFormular->setChecked(m_pTable->getShowFormular());
-    m_LcMode->setChecked(m_pTable->getLcMode());
-    m_showColumnNumber->setChecked(m_pTable->getShowColumnNumber());
+
     /*recalc all dependent after loading*/
     KSpreadTable *tbl;
     for ( tbl = m_pDoc->map()->firstTable(); tbl != 0L; tbl = m_pDoc->map()->nextTable() )
 	tbl->recalc(true);
-    m_bLoading =true;    
+    m_bLoading =true;
 }
 
 /*
@@ -536,7 +542,7 @@ bool KSpreadView::eventKeyPressed( QKeyEvent* _event, bool choose )
 	    updateEditWidget();
 	break;
 
-    case Key_Up:	
+    case Key_Up:
 	(m_pCanvas->*hideMarker)();
 
 	if ( selection.left() == 0 && make_select )
@@ -581,7 +587,7 @@ bool KSpreadView::eventKeyPressed( QKeyEvent* _event, bool choose )
 
     case Key_Left:
 	(m_pCanvas->*hideMarker)();
-	
+
 	if ( selection.left() == 0 && make_select )
 	    selection = QRect( marker_column, marker_row, 1, 1 );
 
@@ -665,7 +671,7 @@ bool KSpreadView::eventKeyPressed( QKeyEvent* _event, bool choose )
 	}
 	else if ( choose )
 	    m_pTable->setChooseRect( QRect( m_pCanvas->chooseMarkerColumn(), m_pCanvas->chooseMarkerRow(), 1, 1 ) );
-	
+
 	(m_pCanvas->*showMarker)();
 
 	if ( !choose )
@@ -698,6 +704,7 @@ void KSpreadView::updateEditWidget()
     m_bold->setChecked( cell->textFontBold() );
     m_italic->setChecked( cell->textFontItalic() );
     m_underline->setChecked( cell->textFontUnderline() );
+    m_strikeOut->setChecked( cell->textFontStrike() );
     m_textColor->setColor( cell->textColor() );
     m_bgColor->setColor( cell->bgColor() );
 
@@ -721,6 +728,8 @@ void KSpreadView::updateEditWidget()
     else if ( cell->alignY() == KSpreadLayout::Bottom )
 	m_alignBottom->setChecked( TRUE );
 
+    m_verticalText->setChecked( cell->verticalText() );
+
     m_multiRow->setChecked( cell->multiRow() );
     if( cell->faktor()==100.0 && cell->postfix()=="%")
     	m_percent->setChecked( TRUE );
@@ -732,6 +741,16 @@ void KSpreadView::updateEditWidget()
     else
     	m_money->setChecked( FALSE );
 
+    if( cell->getComment().isEmpty())
+        {
+        m_showComment->setEnabled(FALSE);
+        m_removeComment->setEnabled(FALSE);
+        }
+    else
+        {
+        m_showComment->setEnabled(TRUE);
+        m_removeComment->setEnabled(TRUE);
+        }
     m_toolbarLock = FALSE;
 }
 
@@ -766,7 +785,6 @@ void KSpreadView::updateReadWrite( bool readwrite )
   //  m_newView->setEnabled( true );
   m_pDoc->KXMLGUIClient::action( "newView" )->setEnabled( true );
   m_gotoCell->setEnabled( true );
-//  m_help->setEnabled( true );
   m_oszi->setEnabled( true );
 }
 
@@ -808,7 +826,7 @@ void KSpreadView::formulaBrackets()
 void KSpreadView::formulaFraction()
 {
     activateFormulaEditor();
-	
+
     canvasWidget()->insertFormulaChar(Box::DIVIDE );
 }
 
@@ -918,7 +936,7 @@ void KSpreadView::autoSum()
 	    cell = activeTable()->cellAt( --c, m_pCanvas->markerRow() );
 	}
 	while ( cell && cell->isValue() );
-	
+
 	if ( c + 1 < m_pCanvas->markerColumn() )
         {
 	    m_pTable->setChooseRect( QRect( c + 1, m_pCanvas->markerRow(), m_pCanvas->markerColumn() - c - 1, 1 ) );
@@ -981,7 +999,7 @@ void KSpreadView::changeBorderColor()
 
 void KSpreadView::helpUsing()
 {
-  kapp->invokeHTMLHelp( "kspread/kspread.html", QString::null );
+  kapp->invokeHelp( );
 }
 
 QButton * KSpreadView::newIconButton( const char *_file, bool _kbutton, QWidget *_parent )
@@ -1137,7 +1155,24 @@ void KSpreadView::upper()
     updateEditWidget();
 }
 
+void KSpreadView::firstLetterUpper()
+{
+    if( !m_pTable  )
+	return;
+    m_pTable->setSelectionfirstLetterUpper( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ) );
+    updateEditWidget();
+}
 
+void KSpreadView::verticalText(bool b)
+{
+    if( !m_pTable  )
+	return;
+    m_pTable->setSelectionVerticalText( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ),b );
+    QRect r( activeTable()-> selectionRect() );
+    if( r.right() !=0x7FFF && r.bottom() !=0x7FFF)
+        adjust();
+    updateEditWidget();
+}
 
 void KSpreadView::insertFormula()
 {
@@ -1214,6 +1249,14 @@ void KSpreadView::underline( bool b )
     m_pTable->setSelectionFont( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), 0L, -1, -1, -1 ,b );
 }
 
+void KSpreadView::strikeOut( bool b )
+{
+    if ( m_toolbarLock )
+	return;
+    if ( m_pTable == 0 )
+	return;
+    m_pTable->setSelectionFont( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), 0L, -1, -1, -1 ,-1,b );
+}
 
 
 void KSpreadView::italic( bool b )
@@ -1228,24 +1271,24 @@ void KSpreadView::italic( bool b )
 
 void KSpreadView::sortInc()
 {
-QRect r( activeTable()-> selectionRect() );
-if ( r.left() == 0 || r.top() == 0 ||
+  QRect r( activeTable()-> selectionRect() );
+  if ( r.left() == 0 || r.top() == 0 ||
        r.right() == 0 || r.bottom() == 0 )
-  	{
-  	KMessageBox::error( this, i18n("One cell was selected!") );
-	}
-else if( r.right() ==0x7FFF)
-	{
-	 KMessageBox::error( this, i18n("Area too large!") );
-	}
-else if(r.bottom()==0x7FFF)
-	{
-	 KMessageBox::error( this, i18n("Area too large!") );
-	}
-else
-	{
-	activeTable()->sortByColumn( r.left());
-	}
+  {
+    KMessageBox::error( this, i18n("One cell was selected!") );
+  }
+  else if( r.right() ==0x7FFF)
+  {
+    KMessageBox::error( this, i18n("Area too large!") );
+  }
+  else if(r.bottom()==0x7FFF)
+  {
+    KMessageBox::error( this, i18n("Area too large!") );
+  }
+  else
+  {
+    activeTable()->sortByColumn( r.left());
+  }
 }
 
 
@@ -1418,7 +1461,7 @@ if ( m_pTable != 0L )
 }
 void KSpreadView::addTable( KSpreadTable *_t )
 {
-    if( !_t->isHide() )
+    if( !_t->isHidden() )
     {
   	m_pTabBar->addTab( _t->tableName() );
 	setActiveTable( _t );
@@ -1432,8 +1475,6 @@ void KSpreadView::addTable( KSpreadTable *_t )
     QObject::connect( _t, SIGNAL( sig_updateView( KSpreadTable* ) ), SLOT( slotUpdateView( KSpreadTable* ) ) );
     QObject::connect( _t, SIGNAL( sig_updateView( KSpreadTable *, const QRect& ) ),
 		      SLOT( slotUpdateView( KSpreadTable*, const QRect& ) ) );
-    QObject::connect( _t, SIGNAL( sig_updateCell( KSpreadTable *, KSpreadCell*, int, int ) ),
-		      SLOT( slotUpdateCell( KSpreadTable *, KSpreadCell*, int, int ) ) );
     QObject::connect( _t, SIGNAL( sig_unselect( KSpreadTable *, const QRect& ) ),
 		      SLOT( slotUnselect( KSpreadTable *, const QRect& ) ) );
     QObject::connect( _t, SIGNAL( sig_updateHBorder( KSpreadTable * ) ),
@@ -1456,13 +1497,7 @@ void KSpreadView::addTable( KSpreadTable *_t )
     QObject::connect( _t, SIGNAL( sig_polygonInvalidated( const QPointArray& ) ),
 		      this, SLOT( repaintPolygon( const QPointArray& ) ) );
     if(m_bLoading)
-    	{
-    	m_hideGrid->setChecked( !m_pTable->getShowGrid() );
-    	m_showPageBorders->setChecked( m_pTable->isShowPageBorders());
-    	m_showFormular->setChecked(m_pTable->getShowFormular());
-    	m_LcMode->setChecked(m_pTable->getLcMode());
-	m_showColumnNumber->setChecked(m_pTable->getShowColumnNumber());
-    	}
+        m_showPageBorders->setChecked( m_pTable->isShowPageBorders());
 }
 
 void KSpreadView::removeTable( KSpreadTable *_t )
@@ -1524,7 +1559,7 @@ void KSpreadView::changeTable( const QString& _name )
     KSpreadTable *t = m_pDoc->map()->findTable( _name );
     if ( !t )
     {
-	kdDebug(36001) << "Unknown table " << _name.latin1() << endl;
+	kdDebug(36001) << "Unknown table " << _name << endl;
 	return;
     }
 
@@ -1532,11 +1567,7 @@ void KSpreadView::changeTable( const QString& _name )
 
     updateEditWidget();
     //refresh toggle button
-    m_hideGrid->setChecked( !m_pTable->getShowGrid() );
     m_showPageBorders->setChecked( m_pTable->isShowPageBorders());
-    m_showFormular->setChecked(m_pTable->getShowFormular());
-    m_LcMode->setChecked(m_pTable->getLcMode());
-    m_showColumnNumber->setChecked(m_pTable->getShowColumnNumber());
 
 }
 
@@ -1564,6 +1595,7 @@ void KSpreadView::insertTable()
 {
   KSpreadTable *t = m_pDoc->createTable();
   m_pDoc->addTable( t );
+  updateEditWidget();
 }
 
 void KSpreadView::hideTable()
@@ -1581,7 +1613,6 @@ void KSpreadView::showTable()
     dlg->show();
 }
 
-
 void KSpreadView::copySelection()
 {
   if ( m_pTable )
@@ -1636,6 +1667,21 @@ void KSpreadView::specialPaste()
     updateEditWidget();
 }
 
+void KSpreadView::removeComment()
+{
+  if ( !m_pTable )
+	return;
+  m_pTable->setSelectionRemoveComment( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ) );
+  updateEditWidget();
+}
+
+void KSpreadView::showComment()
+{
+  if ( !m_pTable )
+	return;
+  m_pCanvas->showComment();
+}
+
 void KSpreadView::consolidate()
 {
     KSpreadConsolidate* dlg = new KSpreadConsolidate( this, "Consolidate" );
@@ -1792,39 +1838,26 @@ void KSpreadView::togglePageBorders( bool mode )
    m_pTable->setShowPageBorders( mode );
 }
 
-void KSpreadView::toggleGrid( bool mode)
-{
-  if ( !m_pTable )
-       return;
-  m_pTable->setShowGrid(!mode);
-  m_pCanvas->repaint();
-}
 
-void KSpreadView::toggleFormular( bool mode)
+void KSpreadView::preference()
 {
   if ( !m_pTable )
        return;
-  m_pTable->setShowFormular(mode);
+  KSpreadpreference* dlg = new KSpreadpreference( this, "Preference");
+  dlg->show();
   m_pTable->recalc();
   m_pCanvas->repaint();
-
+  slotUpdateHBorder(activeTable());
 }
 
-void KSpreadView::toggleLcMode( bool mode)
+void KSpreadView::addModifyComment()
 {
   if ( !m_pTable )
        return;
-  m_pTable->setLcMode(mode);
-  m_pCanvas->repaint();
-  slotUpdateHBorder(activeTable());
-}
 
-void KSpreadView::toggleColumnNumber(bool mode)
-{
- if ( !m_pTable )
-       return;
-  m_pTable->setShowColumnNumber(mode);
-  slotUpdateHBorder(activeTable());
+  KSpreadcomment* dlg = new  KSpreadcomment( this, "comment",QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ));
+  dlg->show();
+  updateEditWidget();
 }
 
 void KSpreadView::editCell()
@@ -1921,23 +1954,23 @@ void KSpreadView::popupColumnMenu(const QPoint & _point)
 
     m_pPopupColumn= new QPopupMenu();
 
-    m_pPopupColumn->insertItem( KSBarIcon("colin"),i18n("Insert Column"), this, SLOT( slotInsertColumn() ) );
-    m_pPopupColumn->insertItem( KSBarIcon("colout"),i18n("Remove Column"), this, SLOT( slotRemoveColumn() ) );
-    m_pPopupColumn->insertItem( KSBarIcon("resizecol"),i18n("Resize..."), this, SLOT( slotResizeColumn() ) );
-    m_pPopupColumn->insertItem( i18n("Adjust Column"), this, SLOT(slotAdjustColumn() ) );
+    m_pPopupColumn->insertItem( KSBarIcon("insert_table_col"),i18n("Insert Column"), this, SLOT( slotPopupInsertColumn() ) );
+    m_pPopupColumn->insertItem( KSBarIcon("delete_table_col"),i18n("Remove Column"), this, SLOT( slotPopupRemoveColumn() ) );
+    m_pPopupColumn->insertItem( KSBarIcon("resizecol"),i18n("Resize..."), this, SLOT( slotPopupResizeColumn() ) );
+    m_pPopupColumn->insertItem( i18n("Adjust Column"), this, SLOT(slotPopupAdjustColumn() ) );
     QObject::connect( m_pPopupColumn, SIGNAL(activated( int ) ), this, SLOT(slotActivateTool( int ) ) );
 
     m_pPopupColumn->popup( _point );
 }
 
-void KSpreadView::slotAdjustColumn()
+void KSpreadView::slotPopupAdjustColumn()
 {
     if ( !m_pTable )
        return;
     canvasWidget()->hBorderWidget()->adjustColumn();
 }
 
-void KSpreadView::slotResizeColumn()
+void KSpreadView::slotPopupResizeColumn()
 {
     if ( !m_pTable )
 	return;
@@ -1945,7 +1978,7 @@ void KSpreadView::slotResizeColumn()
     dlg->show();
 }
 
-void KSpreadView::slotInsertColumn()
+void KSpreadView::slotPopupInsertColumn()
 {
     m_pTable->insertColumn( m_pHBorderWidget->markerColumn() );
     KSpreadTable *tbl;
@@ -1958,7 +1991,7 @@ void KSpreadView::slotInsertColumn()
     updateEditWidget();
 }
 
-void KSpreadView::slotRemoveColumn()
+void KSpreadView::slotPopupRemoveColumn()
 {
     m_pTable->deleteColumn( m_pHBorderWidget->markerColumn() );
     KSpreadTable *tbl;
@@ -1983,23 +2016,23 @@ void KSpreadView::popupRowMenu(const QPoint & _point )
 
     m_pPopupRow= new QPopupMenu();
 
-    m_pPopupRow->insertItem( KSBarIcon("rowin"),i18n("Insert Row"), this, SLOT( slotInsertRow() ) );
-    m_pPopupRow->insertItem( KSBarIcon("rowout"),i18n("Remove Row"), this, SLOT( slotRemoveRow() ) );
-    m_pPopupRow->insertItem( KSBarIcon("resizerow"),i18n("Resize..."), this, SLOT( slotResizeRow() ) );
-    m_pPopupRow->insertItem( i18n("Adjust Row"), this, SLOT( slotAdjustRow() ) );
+    m_pPopupRow->insertItem( KSBarIcon("insert_table_row"),i18n("Insert Row"), this, SLOT( slotPopupInsertRow() ) );
+    m_pPopupRow->insertItem( KSBarIcon("delete_table_row"),i18n("Remove Row"), this, SLOT( slotPopupRemoveRow() ) );
+    m_pPopupRow->insertItem( KSBarIcon("resizerow"),i18n("Resize..."), this, SLOT( slotPopupResizeRow() ) );
+    m_pPopupRow->insertItem( i18n("Adjust Row"), this, SLOT( slotPopupAdjustRow() ) );
 
     QObject::connect( m_pPopupRow, SIGNAL( activated( int ) ), this, SLOT( slotActivateTool( int ) ) );
     m_pPopupRow->popup( _point );
 }
 
-void KSpreadView::slotAdjustRow()
+void KSpreadView::slotPopupAdjustRow()
 {
     if ( !m_pTable )
        return;
     canvasWidget()->vBorderWidget()->adjustRow();
 }
 
-void KSpreadView::slotResizeRow()
+void KSpreadView::slotPopupResizeRow()
 {
     if ( !m_pTable )
        return;
@@ -2007,22 +2040,26 @@ void KSpreadView::slotResizeRow()
     dlg->show();
 }
 
-void KSpreadView::slotInsertRow()
+void KSpreadView::slotPopupInsertRow()
 {
+    kdDebug(36001) << "KSpreadView::slotPopupInsertRow()" << endl;
     m_pTable->insertRow( m_pVBorderWidget->markerRow() );
 
+    kdDebug(36001) << "KSpreadView::slotPopupInsertRow() : recalc all tables" << endl;
     KSpreadTable *tbl;
     for ( tbl = m_pDoc->map()->firstTable(); tbl != 0L; tbl = m_pDoc->map()->nextTable() )
 	tbl->recalc(true);
 
+    kdDebug(36001) << "KSpreadView::slotPopupInsertRow() : changeNameCellRef" << endl;
     QListIterator<KSpreadTable> it( m_pTable->map()->tableList() );
     for( ; it.current(); ++it )
 	it.current()->changeNameCellRef( m_pVBorderWidget->markerRow(),KSpreadTable::RowInsert,m_pTable->name());
+    kdDebug(36001) << "KSpreadView::slotPopupInsertRow() : changeNameCellRef done" << endl;
 
     updateEditWidget();
 }
 
-void KSpreadView::slotRemoveRow()
+void KSpreadView::slotPopupRemoveRow()
 {
     m_pTable->deleteRow( m_pVBorderWidget->markerRow() );
 
@@ -2059,28 +2096,27 @@ void KSpreadView::openPopupMenu( const QPoint & _point )
     m_adjust->plug( m_pPopupMenu );
     m_default->plug( m_pPopupMenu );
     m_areaName->plug( m_pPopupMenu );
-    /* m_pPopupMenu->insertItem( i18n("Layout"), this, SLOT( layoutDlg() ) );
-    m_pPopupMenu->insertItem( i18n("Copy"), this, SLOT( slotCopy() ) );
-    m_pPopupMenu->insertItem( i18n("Cut"), this, SLOT( slotCut() ) );
-    m_pPopupMenu->insertItem( i18n("Paste"), this, SLOT( slotPaste() ) );
-    m_pPopupMenu->insertItem( i18n("Special Paste"), this,SLOT(slotSpecialPaste() ) );
-    m_pPopupMenu->insertItem(i18n("Delete"), this, SLOT(slotDelete() ) );
-    m_pPopupMenu->insertItem( i18n("Adjust"),this,SLOT(slotAdjust()));
-    m_pPopupMenu->insertItem(i18n("Clear"),this,SLOT(slotClear())); */
-
     // If there is no selection
     QRect selection( m_pTable->selectionRect() );
     if(selection.left()==0 && koDocument()->isReadWrite() )
     {
     	m_pPopupMenu->insertSeparator();
-    	m_pPopupMenu->insertItem( i18n("Insert Cell"),this,SLOT(slotInsert()));
-    	m_pPopupMenu->insertItem( i18n("Remove Cell"),this,SLOT(slotRemove()));
+        m_insertCell->plug( m_pPopupMenu );
+        m_removeCell->plug( m_pPopupMenu );
     }
+    KSpreadCell *cell = m_pTable->cellAt( m_pCanvas->markerColumn(), m_pCanvas->markerRow() );
+    m_pPopupMenu->insertSeparator();
+    m_addModifyComment->plug( m_pPopupMenu );
+    if(!cell->getComment().isEmpty())
+        {
+        m_showComment->plug( m_pPopupMenu );
+        m_removeComment->plug( m_pPopupMenu );
+        }
 
     // Remove informations about the last tools we offered
     m_lstTools.clear();
     m_lstTools.setAutoDelete( true );
-    KSpreadCell *cell = m_pTable->cellAt( m_pCanvas->markerColumn(), m_pCanvas->markerRow() );
+
     if ( !cell->isFormular() && !cell->isValue() && !cell->valueString().isEmpty()&& koDocument()->isReadWrite() )
     {
       m_popupMenuFirstToolId = 10;
@@ -2109,7 +2145,7 @@ void KSpreadView::openPopupMenu( const QPoint & _point )
 	    m_lstTools.append( t );
 	  }
 	}
-	
+
 	QObject::connect( m_pPopupMenu, SIGNAL( activated( int ) ), this, SLOT( slotActivateTool( int ) ) );
       }
     }
@@ -2139,37 +2175,8 @@ void KSpreadView::slotActivateTool( int _id )
 
   QString text = cell->text();
   if ( tool->run( entry->command, &text, "QString", "text/plain") )
-      cell->setText( text );
+      cell->setCellText( text, true );
 
-  // ############## TODO
-  /*
-//  CORBA::Object_var obj = imr_activate( entry->entry->name(), "IDL:DataTools/Tool:1.0" );
-  CORBA::Object_var obj = entry->entry->ref();
-  if ( CORBA::is_nil( obj ) )
-    // TODO: error message
-    return;
-
-  DataTools::Tool_var tool = DataTools::Tool::_narrow( obj );
-  if ( CORBA::is_nil( tool ) )
-    // TODO: error message
-    return;
-
-  KSpreadCell *cell = m_pTable->cellAt( m_pCanvas->markerColumn(), m_pCanvas->markerRow() );
-  if ( !cell->isFormular() && !cell->isValue() )
-  {
-    QString text = cell->text();
-    CORBA::Any value;
-    value <<= CORBA::Any::from_string( (char*)text.data(), 0 );
-    CORBA::Any anyid;
-    KSpread::DataToolsId id;
-    id.time = (unsigned long int)time( 0L );
-    id.row = m_pCanvas->markerRow();
-    id.column = m_pCanvas->markerColumn();
-    anyid <<= id;
-    tool->run( entry->command.ascii(), this, value, anyid );
-    return;
-  }
-  */
 }
 
 void KSpreadView::deleteSelection()
@@ -2242,7 +2249,7 @@ void KSpreadView::showAreaName()
 
 void KSpreadView::resizeRow()
 {
-    QRect selection( activeTable()->selectionRect() ); 
+    QRect selection( activeTable()->selectionRect() );
     if(selection.bottom()==0x7FFF)
     	KMessageBox::error( this, i18n("Area too large!"));
     else
@@ -2254,11 +2261,11 @@ void KSpreadView::resizeRow()
 
 void KSpreadView::resizeColumn()
 {
-    QRect selection( activeTable()->selectionRect() ); 
+    QRect selection( activeTable()->selectionRect() );
     if(selection.right()==0x7FFF)
     	KMessageBox::error( this, i18n("Area too large!"));
     else
-    	{	
+    	{
 	KSpreadresize2* dlg = new KSpreadresize2( this, "Resize column", KSpreadresize2::resize_column );
     	dlg->show();
     	}
@@ -2266,7 +2273,7 @@ void KSpreadView::resizeColumn()
 
 void KSpreadView::equalizeRow()
 {
-    QRect selection( activeTable()->selectionRect() ); 
+    QRect selection( activeTable()->selectionRect() );
     if(selection.bottom()==0x7FFF)
     	KMessageBox::error( this, i18n("Area too large!"));
     else
@@ -2277,11 +2284,11 @@ void KSpreadView::equalizeRow()
 
 void KSpreadView::equalizeColumn()
 {
-    QRect selection( activeTable()->selectionRect() ); 
+    QRect selection( activeTable()->selectionRect() );
     if(selection.right()==0x7FFF)
     	KMessageBox::error( this, i18n("Area too large!"));
     else
-    	{	
+    	{
 	canvasWidget()->equalizeColumn();
     	}
 }
@@ -2331,33 +2338,40 @@ void KSpreadView::alignLeft( bool b )
 {
     if ( m_toolbarLock )
 	return;
-    if ( !b )
-	return;
-
     if ( m_pTable != 0L )
-	m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Left );
+        {
+        if ( !b )
+                m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Undefined );
+        else
+	        m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Left );
+        }
 }
 
 void KSpreadView::alignRight( bool b )
 {
     if ( m_toolbarLock )
 	return;
-    if ( !b )
-	return;
-
     if ( m_pTable != 0L )
-      m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Right );
+        {
+        if ( !b )
+	        m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Undefined );
+        else
+                m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Right );
+        }
 }
 
 void KSpreadView::alignCenter( bool b )
 {
     if ( m_toolbarLock )
 	return;
-    if ( !b )
-	return;
 
     if ( m_pTable != 0L )
-	m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Center );
+        {
+        if ( !b )
+                m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Undefined );
+        else
+	        m_pTable->setSelectionAlign( QPoint( m_pCanvas->markerColumn(), m_pCanvas->markerRow() ), KSpreadLayout::Center );
+        }
 }
 
 void KSpreadView::alignTop( bool b )
@@ -2489,7 +2503,7 @@ void KSpreadView::removeTable()
     }
     QApplication::beep();
     int ret = KMessageBox::warningYesNo(this,i18n("You are going to remove the active table.\nDo you want to continue?"),i18n("Remove table"));
-                                
+
     if ( ret == 3 )
     {
         KSpreadTable *tbl = activeTable();
@@ -2611,21 +2625,6 @@ void KSpreadView::slotChangeSelection( KSpreadTable *_table, const QRect &_old,
 	m_pHBorderWidget->update();
 }
 
-// ############ Not needed any more since the signal it connects to is not needed
-void KSpreadView::slotUpdateCell( KSpreadTable *_table, KSpreadCell *_cell, int _col, int _row )
-{
-    // qDebug("void KSpreadView::slotUpdateCell( KSpreadTable *_table, KSpreadCell *_cell, _col=%i, _row=%i )\n",_col,_row);
-
-    // Do we display this table ?
-    if ( _table != m_pTable )
-	return;
-
-    m_pCanvas->drawCell( _cell, _col, _row );
-
-    if ( _col == m_pCanvas->markerColumn() && _row == m_pCanvas->markerRow() )
-	updateEditWidget();
-}
-
 void KSpreadView::slotUnselect( KSpreadTable *_table, const QRect& _old )
 {
     // Do we display this table ?
