@@ -13,34 +13,37 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
-#include <KoApplication.h>
+#include <koApplication.h>
+#include <kaboutdata.h>
 #include <kcmdlineargs.h>
+#include <klocale.h>
 
 #include <dcopclient.h>
-#include "kspread_aboutdata.h"
+#include "kspread_factory.h"
 
-using namespace KSpread;
 
 static const KCmdLineOptions options[]=
 {
-	{"+[file]", I18N_NOOP("File to open"),0},
-        KCmdLineLastOption
+	{"+[file]", I18N_NOOP("File To Open"),0},
+	{0,0,0}
 };
 
-extern "C" KSPREAD_EXPORT int kdemain( int argc, char **argv )
+int main( int argc, char **argv )
 {
 
-    KCmdLineArgs::init( argc, argv, newAboutData() );
+    KCmdLineArgs::init( argc, argv, KSpreadFactory::aboutData());
     KCmdLineArgs::addCmdLineOptions( options );
 
     KoApplication app;
 
-    if (!app.start())
-	return 1;
+    app.dcopClient()->attach();
+    app.dcopClient()->registerAs( "kspread" );
+
+    app.start();
     app.exec();
     return 0;
 }
