@@ -1,6 +1,6 @@
 /*
 
- $Id: configdlg.cpp,v 1.1.1.1 1999/10/20 10:10:32 kulow Exp $
+ $Id: configdlg.cpp,v 1.3 2000/05/27 18:37:07 mlaurent Exp $
 
  KCalc
 
@@ -26,7 +26,8 @@
 
 #include "configdlg.h"
 
-#include <qcolordialog.h>
+//#include <qcolordialog.h>
+#include <kcolordlg.h>
 
 // Undefine HAVE_LONG_DOUBLE for Beta 4 since RedHat 5.0 comes with a borken
 // glibc
@@ -164,7 +165,6 @@ ConfigDlg::ConfigDlg(QWidget *parent, const char *name, DefStruct *defstruct)
 
 void ConfigDlg::help()
 {
-    // mykapp->invokeHTMLHelp("","");
 }
 
 void ConfigDlg::okButton()
@@ -193,22 +193,23 @@ void ConfigDlg::cancelbutton()
 
 void ConfigDlg::set_fore_color(){
 
-    QColor c = QColorDialog::getColor( defst->forecolor, this );
-    if ( c.isValid() )
-    {
-	defst->forecolor = c;
-	qframe1->setBackgroundColor(defst->forecolor);
-    }
+    //QColor c = QColorDialog::getColor( defst->forecolor, this );
+    if(KColorDialog::getColor( defst->forecolor ) )
+        qframe1->setBackgroundColor(defst->forecolor);
+
 }
 
 void ConfigDlg::set_background_color(){
 
-    QColor c = QColorDialog::getColor( defst->backcolor, this );
-    if ( c.isValid() )
-    {
-	defst->backcolor = c;
-	qframe2->setBackgroundColor(defst->backcolor);
-    }
+    //QColor c = QColorDialog::getColor( defst->backcolor, this );
+    if(KColorDialog::getColor( defst->backcolor ))
+        qframe2->setBackgroundColor(defst->backcolor);
+        /*if ( c.isValid() )
+                {
+	        defst->backcolor = c;
+	        qframe2->setBackgroundColor(defst->backcolor);
+                }*/
+
 }
 
 #include "configdlg.moc"
