@@ -63,6 +63,7 @@ CalcFactory::CalcFactory( QObject* parent, const char* name )
 
 CalcFactory::~CalcFactory()
 {
+    delete s_global; 
 }
 
 QObject* CalcFactory::create( QObject* parent, const char* name, const char* /*classname*/, const QStringList & )
@@ -73,7 +74,9 @@ QObject* CalcFactory::create( QObject* parent, const char* name, const char* /*c
 	return 0;
     }
 
-    return new Calculator( (KSpreadView*)parent, name );
+    QObject *obj = new Calculator( (KSpreadView*)parent, name );
+    emit objectCreated( obj );
+    return obj;
 }
 
 KInstance* CalcFactory::global()
@@ -95,8 +98,9 @@ Calculator::Calculator( KSpreadView* parent, const char* name )
 
     parent->installEventFilter( this );
 
-    (void)new KAction( i18n("Calculator"), "kspreadcalc", 0, this, SLOT( showCalculator() ),
-                       actionCollection(), "kspreadcalc");
+    // HACK: Don't know what to do with the icon (Werner)
+    (void)new KAction( i18n("Calculator"), SmallIcon("kspreadcalc", CalcFactory::global()),
+		       0, this, SLOT( showCalculator() ), actionCollection(), "kspreadcalc");
 }
 
 void Calculator::showCalculator()
