@@ -21,18 +21,18 @@
 
 #include <qpainter.h>
 #include <qbitmap.h>
-#include <qpointarray.h>
-#include <qapplication.h>
-#include <qsocketnotifier.h>
-#include <qpopupmenu.h>
+#include <qpntarry.h>
+#include <qapp.h>
+#include <qsocknot.h>
+#include <qpopmenu.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qkeycode.h>
 #include <qtimer.h>
-#include <qbuttongroup.h>
-#include <qfiledialog.h>
+#include <qbttngrp.h>
+#include <qfiledlg.h>
 #include <qstrlist.h>
-#include <qmessagebox.h>
+#include <qmsgbox.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -110,7 +110,7 @@ void AIPlot::init()
   }
 
   // Setup defaults
-  printer = new KPrinter;
+  printer = new QPrinter;
   bg_buf=NULL;
 
   plottype=AI_PLOT_TREND;
@@ -1283,4 +1283,3 @@ double AICursor::y(void)
   return ypos;
 }
 
-#include "qtai_plot.moc"
