@@ -20,33 +20,41 @@
 #ifndef contents_h
 #define contents_h
 
-class KWTextFrameSet;
-class KMacroCommand;
-class KoStyle;
-#include <korichtext.h>
+#include <qstringlist.h>
 
-// This command inserts a TOC at the beginning of a frameset, and is able to undo that.
-// The reason we don't use KWTextFrameSet's insert, applyStyle etc. is that it would
-// generate many many subcommands (resulting in much memory use).
-class KWInsertTOCCommand : public KoTextDocCommand
+class KWordDocument;
+class KWParag;
+
+class KWContents
 {
 public:
-    // The parag is where the TOC should be inserted
-    KWInsertTOCCommand( KWTextFrameSet *fs, KoTextParag *parag );
-    KoTextCursor *execute( KoTextCursor *c );
-    KoTextCursor *unexecute( KoTextCursor *c );
+    KWContents( KWordDocument *doc_ );
 
-    // Helper method, public for KWTextFrameSet::insertTOC().
-    // Remove a toc based on the parag styles
-    static KoTextCursor * removeTOC( KWTextFrameSet *fs, KoTextCursor *cursor, KMacroCommand *macroCmd );
+    void createContents();
+    void addParagName( const QString &n ) {
+	parags.append( n );
+    }
+    void setEnd( KWParag *e ) {
+	end = e;
+    }
+    bool hasContents() {
+	return end && !parags.isEmpty();
+    }
+    bool numParags() {
+	return parags.count();
+    }
+    QStringList::Iterator begin() {
+	return parags.begin();
+    }
+    QStringList::Iterator ending() {
+	return parags.end();
+    }
 
 protected:
-    // Find or create a toc style
-    static KoStyle * findOrCreateTOCStyle( KWTextFrameSet *fs, int depth );
+    KWordDocument *doc;
+    KWParag *end;
+    QStringList parags;
 
-    int m_paragId;
 };
 
-
-
 #endif
