@@ -78,7 +78,7 @@ KWDocStructFrameItem::KWDocStructFrameItem( QListViewItem *_parent, QString _tex
 void KWDocStructFrameItem::slotDoubleClicked( QListViewItem *_item )
 {
     if ( _item == this )
-        gui->getPaperWidget()->scrollToOffset( frame->x(), frame->y(), *gui->getPaperWidget()->getCursor() );
+        gui->getPaperWidget()->scrollToOffset( frame->x(), frame->y() );
 }
 
 /******************************************************************/
@@ -99,7 +99,7 @@ void KWDocStructTableItem::slotDoubleClicked( QListViewItem *_item )
     if ( _item == this )
     {
         KWFrame *frame = table->getFrameSet( 0, 0 )->getFrame( 0 );
-        gui->getPaperWidget()->scrollToOffset( frame->x(), frame->y(), *gui->getPaperWidget()->getCursor() );
+        gui->getPaperWidget()->scrollToOffset( frame->x(), frame->y() );
     }
 }
 
@@ -121,7 +121,7 @@ void KWDocStructPictureItem::slotDoubleClicked( QListViewItem *_item )
     if ( _item == this )
     {
         KWFrame *frame = pic->getFrame( 0 );
-        gui->getPaperWidget()->scrollToOffset( frame->x(), frame->y(), *gui->getPaperWidget()->getCursor() );
+        gui->getPaperWidget()->scrollToOffset( frame->x(), frame->y() );
     }
 }
 
@@ -143,7 +143,7 @@ void KWDocStructPartItem::slotDoubleClicked( QListViewItem *_item )
     if ( _item == this )
     {
         KWFrame *frame = part->getFrame( 0 );
-        gui->getPaperWidget()->scrollToOffset( frame->x(), frame->y(), *gui->getPaperWidget()->getCursor() );
+        gui->getPaperWidget()->scrollToOffset( frame->x(), frame->y() );
     }
 }
 
@@ -162,27 +162,27 @@ KWDocStructRootItem::KWDocStructRootItem( QListView *_parent, KWordDocument *_do
     switch ( type ) {
     case Arrangement: {
         setText( 0, i18n( "Arrangement" ) );
-        setPixmap( 0, BarIcon( "tree_arrange" ) );
+        setPixmap( 0, KWBarIcon( "tree_arrange" ) );
     } break;
     case TextFrames: {
         setText( 0, i18n( "Text Frames/Frame Sets" ) );
-        setPixmap( 0, BarIcon( "tree_textframes" ) );
+        setPixmap( 0, KWBarIcon( "tree_textframes" ) );
     } break;
     case Tables: {
         setText( 0, i18n( "Tables" ) );
-        setPixmap( 0, BarIcon( "tree_table" ) );
+        setPixmap( 0, KWBarIcon( "tree_table" ) );
     } break;
     case Pictures: {
         setText( 0, i18n( "Pictures" ) );
-        setPixmap( 0, BarIcon( "tree_picture" ) );
+        setPixmap( 0, KWBarIcon( "tree_picture" ) );
     } break;
     case Cliparts: {
         setText( 0, i18n( "Cliparts" ) );
-        setPixmap( 0, BarIcon( "tree_clipart" ) );
+        setPixmap( 0, KWBarIcon( "tree_clipart" ) );
     } break;
     case Embedded: {
         setText( 0, i18n( "Embedded Objects" ) );
-        setPixmap( 0, BarIcon( "tree_embedded" ) );
+        setPixmap( 0, KWBarIcon( "tree_embedded" ) );
     } break;
     }
 }
