@@ -24,7 +24,6 @@
 #include <klocale.h>
 #include <kimageio.h>
 #include <kglobal.h>
-#include <kiconloader.h>
 #include <kstddirs.h>
 #include <qstringlist.h>
 #include <kcmdlineargs.h>
@@ -35,8 +34,6 @@ KoApplication::KoApplication()
 {
     // Install the libkoffice* translations
     KGlobal::locale()->insertCatalogue("koffice");
-    // Tell the iconloader about share/apps/koffice/icons
-    KGlobal::instance()->iconLoader()->addAppDir("koffice");
 
     KImageIO::registerFormats();
 
