@@ -157,6 +157,10 @@ bool KoDocument::singleViewMode() const
   return d->m_bSingleViewMode;
 }
 
+bool KoDocument::isEmbedded() const {
+  return parent() && parent()->inherits( "KoDocument" );
+}
+
 bool KoDocument::saveFile()
 {
   kdDebug(30003) << "KoDocument::saveFile()" << endl;
@@ -219,9 +223,9 @@ KAction *KoDocument::action( const QDomElement &element ) const
   return d->m_views.getFirst()->action( element );
 }
 
-QDomDocument KoDocument::document() const
+QDomDocument KoDocument::domDocument() const
 {
-  return d->m_views.getFirst()->document();
+  return d->m_views.getFirst()->domDocument();
 }
 
 void KoDocument::setManager( KParts::PartManager *manager )
