@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (c) 2000 Simon Hausmann <hausmann@kde.org>
 
-   $Id: koDocumentInfoDlg.h,v 1.11 2003/07/12 06:55:31 tokoe Exp $
+   $Id: koDocumentInfoDlg.h,v 1.5 2000/05/02 08:24:22 hausmann Exp $
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,13 +22,15 @@
 #ifndef __koDocumentInfoDlg_h__
 #define __koDocumentInfoDlg_h__
 
-#include <kpropertiesdialog.h>
+#include <qobject.h>
+
+#include <kpropsdlg.h>
 
 class KDialogBase;
 class KoDocumentInfo;
 class KoDocumentInfoAuthor;
 class KoDocumentInfoAbout;
-class KArchiveEntry;
+class KTarEntry;
 
 class KoDocumentInfoDlg : public QObject
 {
@@ -46,9 +48,6 @@ public:
 signals:
   void changed();
 
-private slots:
-  void loadFromKABC();
-
 private:
   void addAuthorPage( KoDocumentInfoAuthor *authorInfo );
   void addAboutPage( KoDocumentInfoAbout *aboutInfo );
@@ -60,18 +59,17 @@ private:
   KoDocumentInfoDlgPrivate *d;
 };
 
-class KoDocumentInfoPropsPage : public KPropsDlgPlugin
+class KoDocumentInfoPropsPage : public KPropsPage
 {
   Q_OBJECT
 public:
-  KoDocumentInfoPropsPage( KPropertiesDialog *props, const char *name = 0,
-                           const QStringList & = QStringList() );
+  KoDocumentInfoPropsPage( KPropertiesDialog *props );
   virtual ~KoDocumentInfoPropsPage();
 
   virtual void applyChanges();
 
 private:
-  void copy( const QString &path, const KArchiveEntry *entry );
+  void copy( const QString &path, const KTarEntry *entry );
   class KoDocumentInfoPropsPagePrivate;
   KoDocumentInfoPropsPagePrivate *d;
 };
