@@ -6,6 +6,8 @@
 #include <kparts/event.h>
 #include <kdebug.h>
 
+#define QMAX32767(a,b) QMAX(QMAX(32767,a),b)
+
 class KoFramePrivate
 {
 public:
@@ -57,8 +59,12 @@ void KoFrame::setView( KoView *view )
   {
     d->m_view->installEventFilter( this );
 
-    setMaximumSize( QMAX( d->m_view->maximumWidth() + 2 * border(), d->m_view->maximumWidth() ),
-		    QMAX( d->m_view->maximumHeight() + 2 * border(), d->m_view->maximumHeight() ) );
+    // #### Do we need this ?
+    // 1 - it seems border is 0
+    // 2 - setState will be called anyway
+    // (David)
+    setMaximumSize( QMAX32767( d->m_view->maximumWidth() + 2 * border(), d->m_view->maximumWidth() ),
+		    QMAX32767( d->m_view->maximumHeight() + 2 * border(), d->m_view->maximumHeight() ) );
     setMinimumSize( d->m_view->minimumWidth() + leftBorder() + rightBorder(),
 		    d->m_view->minimumHeight() + topBorder() + bottomBorder() );
 
@@ -82,8 +88,14 @@ void KoFrame::setState( State s )
 
   if ( d->m_view )
   {
-      setMaximumSize( QMAX( d->m_view->maximumWidth() + 2 * border(), d->m_view->maximumWidth() ),
-		      QMAX( d->m_view->maximumHeight() + 2 * border(), d->m_view->maximumHeight() ) );
+      /*
+      kdDebug(30003) << "KoFrame::setView setMaximumSize "
+              << "QMAX32767(" << d->m_view->maximumWidth() + 2 * border() << "," << d->m_view->maximumWidth() << "), "
+              << "QMAX32767(" << d->m_view->maximumHeight() + 2 * border() << "," <<  d->m_view->maximumHeight() << ")"
+              << endl;
+      */
+      setMaximumSize( QMAX32767( d->m_view->maximumWidth() + 2 * border(), d->m_view->maximumWidth() ),
+		      QMAX32767( d->m_view->maximumHeight() + 2 * border(), d->m_view->maximumHeight() ) );
       setMinimumSize( d->m_view->minimumWidth() + leftBorder() + rightBorder(),
 		      d->m_view->minimumHeight() + topBorder() + bottomBorder() );
   }
@@ -235,6 +247,10 @@ void KoFrame::mouseMoveEvent( QMouseEvent* ev )
       QPoint p = parentWidget()->mapFromGlobal( ev->globalPos() );
       move( QPoint( p.x() + d->m_framePos.x() - d->m_mousePressPos.x(),
 		    p.y() + d->m_framePos.y() - d->m_mousePressPos.y() ) );
+      // The other modes change the geometry so they call resizeEvent.
+      // This one doesn't, so it has to emit geometryChangedby itself.
+      emit geometryChanged();
+      //kdDebug() << "KoFrame::mouseMoveEvent koFrame position is " << x() << "," << y() << endl;
   }
   else if ( d->m_mode == 1 )
   {
