@@ -24,7 +24,6 @@
 #include "koDocument.h"
 #include "koView.h"
 #include "koFilterManager.h"
-#include "koIcons.h"
 #include "koDocumentInfo.h"
 #include "koDocumentInfoDlg.h"
 
@@ -34,6 +33,7 @@
 #include <qmime.h>
 #include <qmessagebox.h>
 #include <qfileinfo.h>
+#include <qsplitter.h>
 
 #include <kaboutdialog.h>
 #include <kstdaction.h>
@@ -49,6 +49,7 @@
 #include <kio/netaccess.h>
 #include <kkeydialog.h>
 #include <kedittoolbar.h>
+#include <kdebug.h>
 
 #include <kparts/partmanager.h>
 #include <kparts/plugin.h>
@@ -67,23 +68,35 @@ public:
   KoMainWindowPrivate()
   {
     m_rootDoc = 0L;
-    m_rootView = 0L;
+    m_rootViews = 0L;
     m_manager = 0L;
     bMainWindowGUIBuilt = false;
     m_activePart = 0L;
     m_activeView = 0L;
+    m_splitViewActionList=0L;
+    m_splitter=0L;
+    m_orientation=0L;
+    m_removeView=0L;
+    m_toolbarList.setAutoDelete( true );
   }
   ~KoMainWindowPrivate()
   {
   }
 
   KoDocument *m_rootDoc;
-  KoView *m_rootView;
+  QList<KoView> *m_rootViews;
   KParts::PartManager *m_manager;
 
   KParts::Part *m_activePart;
   KoView *m_activeView;
 
+  QList<KAction> *m_splitViewActionList;
+  QSplitter *m_splitter;
+  KSelectAction *m_orientation;
+  KAction *m_removeView;
+
+  QList <KAction> m_toolbarList;
+
   bool bMainWindowGUIBuilt;
 };
 
@@ -118,11 +131,8 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
 			this, SLOT( slotDocumentInfo() ),
 			actionCollection(), "file_documentinfo" );
 
-    (void) new KAction( i18n( "Configure &Keys..." ), 0, this,
-      SLOT( slotConfigureKeys() ), actionCollection(), "configurekeys" );
-
-    (void) new KAction( i18n( "Configure Tool&bars..." ), 0, this,
-      SLOT( slotConfigureToolbars() ), actionCollection(), "configuretoolbars" );
+    KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection(), "configurekeys" );
+    KStdAction::configureToolbars( this, SLOT( slotConfigureToolbars() ), actionCollection(), "configuretoolbars" );
 
     KHelpMenu * m_helpMenu = new KHelpMenu( this );
     KStdAction::helpContents( m_helpMenu, SLOT( appHelpActivated() ), actionCollection(), "contents" );
@@ -131,6 +141,22 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     KStdAction::aboutKDE( m_helpMenu, SLOT( aboutKDE() ), actionCollection(), "about_kde" );
     KStdAction::reportBug( m_helpMenu, SLOT( reportBug() ), actionCollection(), "report_bug" );
 
+    // set up the action list for the splitter stuff
+    d->m_splitViewActionList=new QList<KAction>;
+    d->m_splitViewActionList->append(new KAction(i18n("Split View"), 0, this, SLOT(slotSplitView()),
+						actionCollection(), "view_split"));
+    d->m_removeView=new KAction(i18n("Remove View"), 0, this, SLOT(slotRemoveView()),
+				actionCollection(), "view_rm_splitter");
+    d->m_splitViewActionList->append(d->m_removeView);
+    d->m_removeView->setEnabled(false);
+    d->m_orientation=new KSelectAction(i18n("Splitter Orientation"), 0, this, SLOT(slotSetOrientation()),
+				       actionCollection(), "view_splitter_orientation");
+    QStringList items;
+    items << i18n("Vertical")
+	  << i18n("Horizontal");
+    d->m_orientation->setItems(items);
+    d->m_splitViewActionList->append(d->m_orientation);
+
     if ( instance )
       setInstance( instance );
 
@@ -139,13 +165,12 @@ KoMainWindow::KoMainWindow( KInstance *instance, const char* name )
     m_recent->loadEntries( config );
     config->sync();
 
-    // we need this for a proper layout of the toolbars upon startup,
-    // when no real view has been loaded, yet
-    m_dummyWidget = new QWidget( this );
-    setView( m_dummyWidget );
+    d->m_splitter=new QSplitter(Qt::Vertical, this, "funky-splitter");
+    setView( d->m_splitter );
+
+    d->m_rootViews=new QList<KoView>;
 
     buildMainWindowGUI();
-    //createGUI( 0L ); // NOT this ! (duplicates shell entries !)
 
     if (QApplication::desktop()->width() > 1100) // very big desktop ?
         resize( 900, 800 );
@@ -160,8 +185,19 @@ KoMainWindow::~KoMainWindow()
     // The doc and view might still exist (this is the case when closing the window)
     if (d->m_rootDoc)
         d->m_rootDoc->removeShell(this);
-    delete d->m_rootView;
-    if ( d->m_rootDoc && d->m_rootDoc->viewCount() == 0 )
+
+    KoView *view=d->m_rootViews->first();
+    for ( ; view!=0L; view=d->m_rootViews->next()) {
+	delete view;
+	view=0L;
+    }
+    delete d->m_rootViews;
+
+    // We have to check if this was a root document.
+    // -> We aren't allowed to delete the (embedded) document!
+    // This has to be checked from queryClose, too :)
+    if ( d->m_rootDoc && d->m_rootDoc->viewCount() == 0 &&
+	 !d->m_rootDoc->isEmbedded())
     {
         kdDebug(30003) << "Destructor. No more views, deleting old doc " << d->m_rootDoc << endl;
         delete d->m_rootDoc;
@@ -177,14 +213,19 @@ KoMainWindow::~KoMainWindow()
 	s_lstMainWindows->removeRef( this );
 
     delete d->m_manager;
-
+    d->m_splitViewActionList->setAutoDelete(true);
+    d->m_splitViewActionList->clear();
+    delete d->m_splitViewActionList;
+    delete d->m_splitter;
+    d->m_splitter=0L;
     delete d;
 }
 
 void KoMainWindow::setRootDocument( KoDocument *doc )
 {
   kdDebug(30003) <<  "KoMainWindow::setRootDocument this = " << this << " doc = " << doc << endl;
-  KoView *oldRootView = d->m_rootView;
+  QList<KoView> *oldRootViews = new QList<KoView>(*d->m_rootViews);
+  d->m_rootViews->clear();
   KoDocument *oldRootDoc = d->m_rootDoc;
 
   if ( oldRootDoc )
@@ -195,28 +236,25 @@ void KoMainWindow::setRootDocument( KoDocument *doc )
   if ( doc )
   {
     doc->setSelectable( false );
-    d->m_rootView = doc->createView( this );
-    d->m_rootView->setPartManager( d->m_manager );
+    d->m_rootViews->append( doc->createView( d->m_splitter ) );
+    d->m_rootViews->current()->setPartManager( d->m_manager );
 
-    setView( d->m_rootView );
-
-    if ( m_dummyWidget )
-    {
-      delete m_dummyWidget;
-      m_dummyWidget = 0L;
-    }
-    d->m_rootView->show();
+    d->m_rootViews->current()->show();
     d->m_rootDoc->addShell( this );
+    d->m_removeView->setEnabled(false);
   }
-  else
-    d->m_rootView = 0L;
 
   updateCaption();
 
-  d->m_manager->setActivePart( d->m_rootDoc, d->m_rootView );
+  d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews->current() );
+  d->m_orientation->setCurrentItem(static_cast<int>(d->m_splitter->orientation()));
 
-  if ( oldRootView )
-    delete oldRootView;
+  if ( !oldRootViews->isEmpty() ) {
+    for(KoView *view=oldRootViews->first(); view!=0L; view=oldRootViews->next()) {
+      delete view;
+      view=0L;
+    }
+  }
   if ( oldRootDoc && oldRootDoc->viewCount() == 0 )
   {
     kdDebug(30003) << "No more views, deleting old doc " << oldRootDoc << endl;
@@ -248,7 +286,7 @@ void KoMainWindow::updateCaption()
       }
       if ( caption.isEmpty() )
           // Fall back to document URL
-          caption = d->m_rootDoc->url().decodedURL();
+          caption = d->m_rootDoc->url().prettyURL();
 
       // KTMW hides some of the functionality of kapp->makeStdCaption !
       QWidget::setCaption( kapp->makeStdCaption( caption, true, d->m_rootDoc->isModified() ) );
@@ -262,7 +300,7 @@ KoDocument *KoMainWindow::rootDocument() const
 
 KoView *KoMainWindow::rootView() const
 {
-  return (KoView *)view();
+  return d->m_rootViews->first();
 }
 
 KParts::PartManager *KoMainWindow::partManager()
@@ -295,7 +333,7 @@ bool KoMainWindow::openDocument( const KURL & url )
     if ( !newdoc || !newdoc->openURL( url ) )
     {
 	delete newdoc;
-	return FALSE;
+	return false;
     }
 
     if ( doc && doc->isEmpty() )
@@ -317,7 +355,7 @@ bool KoMainWindow::openDocument( const KURL & url )
         // We had no document, set the new one
         setRootDocument( newdoc );
     }
-    return TRUE;
+    return true;
 }
 
 bool KoMainWindow::saveDocument( bool saveas )
@@ -353,8 +391,8 @@ bool KoMainWindow::saveDocument( bool saveas )
 
             // HACK - should we add extension() to KURL ?
 	    if ( QFileInfo( newURL.path() ).extension().isEmpty() ) {
-		// assume a that the the native patterns ends with .extension
-		QString s( nativeFormatPattern() );
+		// assume that the pattern ends with .extension
+		QString s( dialog->currentFilter() );
 		QString extension = s.mid( s.find( "." ) );
 		newURL.setPath( newURL.path() + extension );
 	    }
@@ -384,12 +422,14 @@ bool KoMainWindow::saveDocument( bool saveas )
 bool KoMainWindow::queryClose()
 {
   if ( rootDocument() == 0 )
-    return TRUE;
+    return true;
   kdDebug(30003) << "KoMainWindow::queryClose() viewcount=" << rootDocument()->viewCount() << endl;
-  if ( rootDocument()->viewCount() > 1 ) // last view ?
-    return TRUE; // no, so no problem for closing
+  if ( rootDocument()->viewCount() > 1 )
+    return true; // no, so no problem for closing
 
-  if ( rootDocument()->isModified() )
+  // see DTOR for a descr. for the 2nd test
+  if ( rootDocument()->isModified() &&
+       !rootDocument()->isEmbedded())
   {
       int res = KMessageBox::warningYesNoCancel( 0L,
                     i18n( "The document has been modified\nDo you want to save it ?" ));
@@ -401,11 +441,10 @@ bool KoMainWindow::queryClose()
           case KMessageBox::No :
               break;
           default : // case KMessageBox::Cancel :
-              return FALSE;
+              return false;
       }
   }
-
-  return TRUE;
+  return true;
 }
 
 bool KoMainWindow::closeAllDocuments()
@@ -414,12 +453,11 @@ bool KoMainWindow::closeAllDocuments()
     for( ; win; win = nextMainWindow() )
     {
 	if ( !win->queryClose() )
-	    return FALSE;
+	    return false;
         else
             win->setRootDocument( 0L );
     }
-
-    return TRUE;
+    return true;
 }
 
 void KoMainWindow::slotFileNew()
@@ -432,7 +470,6 @@ void KoMainWindow::slotFileNew()
 	delete newdoc;
 	return;
     }
-
     if ( doc && doc->isEmpty() )
     {
 	setRootDocument( newdoc );
@@ -445,7 +482,6 @@ void KoMainWindow::slotFileNew()
         s->setRootDocument( newdoc );
 	return;
     }
-
     setRootDocument( newdoc );
     return;
 }
@@ -483,7 +519,7 @@ void KoMainWindow::slotFileSave()
 
 void KoMainWindow::slotFileSaveAs()
 {
-    saveDocument( TRUE );
+    saveDocument( true );
 }
 
 void KoMainWindow::slotDocumentInfo()
@@ -538,11 +574,26 @@ void KoMainWindow::slotConfigureToolbars()
   edit.exec();
 }
 
+void KoMainWindow::slotToolbarToggled( bool toggle )
+{
+  // The action (sender) and the toolbar have the same name
+  KToolBar * bar = toolBar( sender()->name() );
+  if (bar)
+  {
+    if (toggle)
+      bar->show();
+    else
+      bar->hide();
+  }
+  else
+    kdWarning(30003) << "slotToolbarToggled : Toolbar " << sender()->name() << " not found!" << endl;
+}
+
 void KoMainWindow::slotHelpAbout()
 {
     KAboutDialog *dia = new KAboutDialog( KAboutDialog::AbtProduct | KAboutDialog::AbtTitle | KAboutDialog::AbtImageOnly,
 					  kapp->caption(),
-					  KDialogBase::Ok, KDialogBase::Ok, this, 0, TRUE );
+					  KDialogBase::Ok, KDialogBase::Ok, this, 0, true );
     dia->setTitle( kapp->caption() );
     dia->setProduct( "", "pre-Beta1", "the KOffice Team", "1998-2000" );
     dia->setImage( locate( "data", "koffice/pics/koffice-logo.png" ) );
@@ -550,6 +601,44 @@ void KoMainWindow::slotHelpAbout()
     delete dia;
 }
 
+void KoMainWindow::slotSplitView() {
+
+    kdDebug(30003) << "KoMainWindow::slotSplitView() called" << endl;
+    d->m_rootViews->append(d->m_rootDoc->createView(d->m_splitter));
+    d->m_rootViews->current()->show();
+    d->m_rootViews->current()->setPartManager( d->m_manager );
+    d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews->current() );
+    d->m_removeView->setEnabled(true);
+}
+
+void KoMainWindow::slotRemoveView() {
+
+    kdDebug(30003) << "KoMainWindow::slotRemoveView() called" << endl;
+
+    KoView *view;
+    if(d->m_rootViews->findRef(d->m_activeView)!=-1)
+        view=d->m_rootViews->current();
+    else
+	view=d->m_rootViews->first();
+    view->hide();
+    d->m_rootViews->removeRef(view);
+
+    if(d->m_rootViews->count()==1)
+	d->m_removeView->setEnabled(false);
+    delete view;
+    view=0L;
+    d->m_rootViews->first()->setPartManager( d->m_manager );
+    d->m_manager->setActivePart( d->m_rootDoc, d->m_rootViews->first() );
+}
+
+void KoMainWindow::slotSetOrientation() {
+
+    kdDebug(30003) << "KoMainWindow::slotSetOrientation() called" << endl;
+    d->m_splitter->setOrientation(static_cast<Qt::Orientation>
+				  (d->m_orientation->currentItem()));
+}
+
+
 void KoMainWindow::buildMainWindowGUI()
 {
   KXMLGUIFactory *factory = guiFactory();
@@ -557,11 +646,11 @@ void KoMainWindow::buildMainWindowGUI()
   QValueList<KXMLGUIClient *>::ConstIterator pIt, pEnd;
   if ( !d->bMainWindowGUIBuilt )
   {
+    factory->addClient( this );
+
     KParts::GUIActivateEvent ev( true );
     QApplication::sendEvent( this, &ev );
 
-    factory->addClient( this );
-
     plugins = KParts::Plugin::pluginClients( this );
     pIt = plugins.begin();
     pEnd = plugins.end();
@@ -574,6 +663,13 @@ void KoMainWindow::buildMainWindowGUI()
 
 void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
 {
+
+  // This looks very much like KParts::MainWindow::createGUI, but we have
+  // to reimplement it because it works with an active part, whereas we work
+  // with an active view _and_ an active part, depending for what.
+  // Both are KXMLGUIClients, but e.g. the plugin query needs a QObject.
+
+
   kdDebug(30003) <<  "KoMainWindow::slotActivePartChanged( Part * newPart) newPart = " <<
     newPart << endl;
   kdDebug(30003) <<  "current active part is " << d->m_activePart << endl;
@@ -593,7 +689,9 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
 
   if ( d->m_activeView )
   {
-    //TODO: event stuff
+    KParts::GUIActivateEvent ev( false );
+    QApplication::sendEvent( d->m_activePart, &ev );
+    QApplication::sendEvent( d->m_activeView, &ev );
 
     plugins = KParts::Plugin::pluginClients( d->m_activeView );
     pIt = plugins.fromLast();
@@ -605,7 +703,10 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
     if ( pIt != plugins.end() )
       factory->removeClient( *pIt );
 
-    factory->removeClient( (KXMLGUIClient *)d->m_activeView );
+    factory->removeClient( d->m_activeView );
+
+    unplugActionList( "toolbarlist" );
+    d->m_toolbarList.clear(); // deletes the actions
   }
 
   buildMainWindowGUI();
@@ -616,22 +717,40 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
     d->m_activePart = newPart;
     kdDebug(30003) <<  "new active part is " << d->m_activePart << endl;
 
-    factory->addClient( (KXMLGUIClient *)d->m_activeView );
+    factory->addClient( d->m_activeView );
+
+    KParts::GUIActivateEvent ev( true );
+    QApplication::sendEvent( d->m_activePart, &ev );
+    QApplication::sendEvent( d->m_activeView, &ev );
 
     plugins = KParts::Plugin::pluginClients( d->m_activeView );
     pIt = plugins.begin();
     pEnd = plugins.end();
     for (; pIt != pEnd; ++pIt )
       factory->addClient( *pIt );
+
+    if(d->m_rootViews->findRef(d->m_activeView)!=-1)
+	factory->plugActionList(d->m_activeView, "view_split", *d->m_splitViewActionList );
+
+    // Create and plug toolbar list for Settings menu
+    QListIterator<KToolBar> it = toolBarIterator();
+    for ( ; it.current() ; ++it )
+    {
+      KToggleAction * act = new KToggleAction( i18n("Show %1 Toolbar").arg( (*it)->text() ), 0,
+                                               actionCollection(), (*it)->name() );
+      connect( act, SIGNAL( toggled( bool ) ), this, SLOT( slotToolbarToggled( bool ) ) );
+      act->setChecked ( true );
+      d->m_toolbarList.append( act );
+    }
+    plugActionList( "toolbarlist", d->m_toolbarList );
+
   }
   else
   {
     d->m_activeView = 0L;
     d->m_activePart = 0L;
   }
-
   setUpdatesEnabled( true );
   updateRects();
 }
-
 #include "koMainWindow.moc"
