@@ -1,38 +1,16 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Reginald Stadlbauer <reggie@kde.org>
-    Copyright (C) 2002 Werner Trobin <trobin@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
-*/
-
-#include <kcoloractions.h>
-
+#include "kcoloractions.h"
+#include <qcstring.h>
+#include "kcoloractions.moc"
 #include <qpopupmenu.h>
-#include <qwhatsthis.h>
-#include <qtooltip.h>
-
-#include <kapplication.h>
+#include <qtoolbar.h>
+#include <qtoolbutton.h>
+#include <qdrawutil.h>
 #include <ktoolbar.h>
-#include <ktoolbarbutton.h>
-#include <kdebug.h>
 
 KColorAction::KColorAction( const QString& text, int accel,
 			    QObject* parent, const char* name )
     : KAction( text, accel, parent, name )
 {
-    typ = TextColor;
     init();
 }
 
@@ -41,7 +19,6 @@ KColorAction::KColorAction( const QString& text, int accel,
 			    const char* name )
     : KAction( text, accel, receiver, slot, parent, name )
 {
-    typ = TextColor;
     init();
 }
 
@@ -49,8 +26,8 @@ KColorAction::KColorAction( const QString& text, Type type, int accel,
 			    QObject* parent, const char* name )
     : KAction( text, accel, parent, name )
 {
-    typ = type;
     init();
+    setType( type );
 }
 
 KColorAction::KColorAction( const QString& text, Type type, int accel,
@@ -58,14 +35,13 @@ KColorAction::KColorAction( const QString& text, Type type, int accel,
 			    const char* name )
     : KAction( text, accel, receiver, slot, parent, name )
 {
-    typ = type;
     init();
+    setType( type );
 }
 
 KColorAction::KColorAction( QObject* parent, const char* name )
     : KAction( parent, name )
 {
-    typ = TextColor;
     init();
 }
 
@@ -100,6 +76,7 @@ KColorAction::Type KColorAction::type() const
 void KColorAction::init()
 {
     col = Qt::black;
+    typ = TextColor;
     createPixmap();
 }
 
@@ -215,134 +192,103 @@ void KColorAction::createPixmap()
     setIconSet( QIconSet( pixmap ) );
 }
 
-
-KSelectColorAction::KSelectColorAction( const QString& text, Type type,
-                                        const QObject* receiver, const char* slot,
-                                        KActionCollection* parent, const char* name ) :
-    KAction( text, KShortcut(), receiver, slot, parent, name ), m_type( type ),
-    m_color( Qt::black )
+KColorBar::KColorBar( const QValueList<QColor> &cols,
+		      QWidget *parent, const char *name )
+    : QWidget( parent, name ), colors( cols )
 {
+    setMinimumSize( 20, colors.count() * 16 + 10 );
+    setMaximumWidth( 20 );
+    resize( minimumSize() );
+    show();
 }
 
-KSelectColorAction::~KSelectColorAction()
+void KColorBar::mousePressEvent( QMouseEvent *e )
 {
+    int index = -1;
+    int x = ( width() - 12 ) / 2;
+    int y = 5;
+    QValueList<QColor>::Iterator it = colors.begin();
+    for ( int i = 0; it != colors.end(); ++it, ++i ) {
+	if ( QRect( x, y, 12, 12 ).contains( e->pos() ) )
+	    index = i;
+	y += 16;
+    }
+
+    if ( index != -1 && index < (int)colors.count() ) {
+	if ( e->button() == LeftButton )
+	    emit leftClicked( colors[ index ] );
+	else if ( e->button() == RightButton )
+	    emit rightClicked( colors[ index ] );
+    }
 }
 
-int KSelectColorAction::plug( QWidget* w, int index )
+void KColorBar::paintEvent( QPaintEvent * )
 {
-    if (w == 0) {
-	kdWarning() << "KSelectColorAction::plug called with 0 argument\n";
- 	return -1;
+    QPainter p;
+    p.begin( this );
+    int x = ( width() - 12 ) / 2;
+    int y = 5;
+    QValueList<QColor>::Iterator it = colors.begin();
+    for ( ; it != colors.end(); ++it ) {
+	qDrawShadePanel( &p, x, y, 12, 12, colorGroup(), TRUE );
+	p.fillRect( x + 1, y + 1, 10, 10, *it );
+	y += 16;
     }
-    if (kapp && !kapp->authorizeKAction(name()))
-        return -1;
+    p.end();
+}
 
-    if ( w->inherits("QPopupMenu") )
-    {
-        QPopupMenu* menu = static_cast<QPopupMenu*>( w );
-        int id;
+KColorBarAction::KColorBarAction( const QString &text, int accel,
+				  QObject *r, const char *leftClickSlot_, const char *rightClickSlot_,
+				  const QValueList<QColor> &cols, QObject *parent, const char *name )
+    : KAction( text, accel, parent, name ), colors( cols )
+{
+    receiver = r;
+    leftClickSlot = qstrdup( leftClickSlot_ );
+    rightClickSlot = qstrdup( rightClickSlot_ );
+}
 
-        if ( hasIcon() )
-        {
-            /* ###### CHECK: We're not allowed to specify the instance in iconSet()
-            KInstance *instance;
-            if ( parentCollection() )
-                instance = parentCollection()->instance();
-            else
-                instance = KGlobal::instance();
-            */
-            id = menu->insertItem( iconSet( KIcon::Small, 0 ), text(), this,//dsweet
-                                   SLOT( slotActivated() ), 0, -1, index );
-        }
-        else
-            id = menu->insertItem( text(), this, SLOT( slotActivated() ),  //dsweet
-                                   0, -1, index );
+int KColorBarAction::plug( QWidget *widget, int index )
+{
+    if ( widget && widget->inherits( "QToolBar" ) ) {
+	QToolBar* bar = (QToolBar*)widget;
+	KColorBar *b;
+	b = new KColorBar( colors, widget, "" );
+	b->resize( 100, 25 );
+	b->show();
+	connect( b, SIGNAL( leftClicked( const QColor & ) ),
+		 this, SIGNAL( leftClicked( const QColor & ) ) );
+	connect( b, SIGNAL( rightClicked( const QColor & ) ),
+		 this, SIGNAL( rightClicked( const QColor & ) ) );
+	connect( b, SIGNAL( leftClicked( const QColor & ) ),
+		 receiver, leftClickSlot );
+	connect( b, SIGNAL( rightClicked( const QColor & ) ),
+		 receiver, rightClickSlot );
 
-        updateShortcut( menu, id );
+	addContainer( bar, b );
+	connect( bar, SIGNAL( destroyed() ), this, SLOT( slotDestroyed() ) );
+	
+	return containerCount() - 1;
+    } else if ( widget && widget->inherits( "KToolBar" ) ) {
+	KToolBar* bar = (KToolBar*)widget;
+	KColorBar *b;
+	b = new KColorBar( colors, widget, "" );
+	bar->insertWidget( -1, b->width(), b, index );
+	b->resize( 100, 25 );
+	b->show();
+	connect( b, SIGNAL( leftClicked( const QColor & ) ),
+		 this, SIGNAL( leftClicked( const QColor & ) ) );
+	connect( b, SIGNAL( rightClicked( const QColor & ) ),
+		 this, SIGNAL( rightClicked( const QColor & ) ) );
+	connect( b, SIGNAL( leftClicked( const QColor & ) ),
+		 receiver, leftClickSlot );
+	connect( b, SIGNAL( rightClicked( const QColor & ) ),
+		 receiver, rightClickSlot );
 
-        // call setItemEnabled only if the item really should be disabled,
-        // because that method is slow and the item is per default enabled
-        if ( !isEnabled() )
-            menu->setItemEnabled( id, false );
-
-        if ( !whatsThis().isEmpty() )
-            menu->setWhatsThis( id, whatsThisWithIcon() );
-
-        addContainer( menu, id );
-        connect( menu, SIGNAL( destroyed() ), this, SLOT( slotDestroyed() ) );
-
-        if ( parentCollection() )
-            parentCollection()->connectHighlight( menu, this );
-
-        return containerCount() - 1;
-    }
-    else if ( w->inherits( "KToolBar" ) )
-    {
-        KToolBar *bar = static_cast<KToolBar *>( w );
-
-        int id_ = getToolButtonID();
-        KInstance *instance;
-        if ( parentCollection() )
-            instance = parentCollection()->instance();
-        else
-            instance = KGlobal::instance();
-
-        if ( icon().isEmpty() ) // old code using QIconSet directly
-        {
-            bar->insertButton( iconSet( KIcon::Small ).pixmap(), id_, SIGNAL( clicked() ), this,
-                               SLOT( slotActivated() ),
-                               isEnabled(), plainText(), index );
-        }
-        else
-            bar->insertButton( icon(), id_, SIGNAL( clicked() ), this,
-                               SLOT( slotActivated() ),
-                               isEnabled(), plainText(), index, instance );
-
-        bar->getButton( id_ )->setName( QCString("toolbutton_")+name() );
-
-        if ( !whatsThis().isEmpty() )
-            QWhatsThis::add( bar->getButton(id_), whatsThisWithIcon() );
-
-        if ( !toolTip().isEmpty() )
-            QToolTip::add( bar->getButton(id_), toolTip() );
-
-        addContainer( bar, id_ );
-
-        connect( bar, SIGNAL( destroyed() ), this, SLOT( slotDestroyed() ) );
-
-        if ( parentCollection() )
-            parentCollection()->connectHighlight( bar, this );
-
-        return containerCount() - 1;
+	addContainer( bar, b );
+	connect( bar, SIGNAL( destroyed() ), this, SLOT( slotDestroyed() ) );
+	
+	return containerCount() - 1;
     }
 
     return -1;
 }
-
-QColor KSelectColorAction::color() const
-{
-    return m_color;
-}
-
-KSelectColorAction::Type KSelectColorAction::type() const
-{
-    return m_type;
-}
-
-void KSelectColorAction::setColor( const QColor &/*c*/ )
-{
-}
-
-void KSelectColorAction::setType( Type /*t*/ )
-{
-}
-
-QString KSelectColorAction::whatsThisWithIcon() const
-{
-    QString text = whatsThis();
-    if (!icon().isEmpty())
-      return QString::fromLatin1("<img source=\"small|%1\"> %2").arg(icon()).arg(text);
-    return text;
-}
-
-#include <kcoloractions.moc>
